<?php
// +---------------------------------------------------------------------------+
// | Media Gallery Plugin 1.5                                                  |
// +---------------------------------------------------------------------------+
// | $Id:: functions.inc 1061 2007-06-21 23:49:20Z mevans0263                 $|
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the media      |
// | gallery PHP files.                                                        |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2004-2006 by the following authors:                         |
// |                                                                           |
// | Author:                                                                   |
// | Mark R. Evans               -    mevans@ecsnet.com                        |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

if (!defined ('VERSION')) {
    die ('This file can not be used on its own.');
}

/**
* Language file Include
*/
$langfile = $_CONF['path'] . 'plugins/mediagallery/language/' . $_CONF['language'] . '.php';

if (file_exists ($langfile)) {
    include_once ($langfile);
} else {
    include_once ($_CONF['path'] . 'plugins/mediagallery/language/english.php');
}

/*
* Include MediaGallery config file
*/
require_once($_CONF['path'] . 'plugins/mediagallery/config.php');
require_once($_MG_CONF['path_html'] . 'common.php');
require_once($_MG_CONF['path_html'] . 'classAlbum.php');

MG_initAlbums();

/** GL 1.3
* User has reuested to create a comment for the plugin
* Redirects user to comment form if initial comment for plugin record or returns
* formated HTML including the Site footer and the comments
*
* @param        int      $comment_id      GL Comment table primary key.
* @param        string   $commentmode     Has user selected a new comment preview mode (Flat, Nested, Threaded, None)
* @param        string   $order           Has the user selected a different comment first (Newest or Oldest comment first)
* @param        string   $reply           Has the user used the reply button on the Comment Bar
* @return       string   Formated HTML containing site footer and the comments with the comment command bar
*                        or redirect user to create top level comment
*/
function plugin_commentform_mediagallery($comment_id,$commentmode='',$order='',$reply='') {
    global $_CONF,$_TABLES, $_USER;

    $commentCount = DB_count($_TABLES['comments'], 'sid', $comment_id);

    $type = "mediagallery";

    if ($commentmode == "") {
        if ($_USER['uid']) {
            $commentmode = DB_getItem($_TABLES['usercomment'],'commentmode',"uid={$_USER['uid']}");
        } else {
            $commentmode = $_CONF['comment_mode'];
        }
    }

    $order = (empty($order) ? "ASC" : $order);

    if ($commentCount == 0 || $reply != "") {
        $pid=0;
        echo COM_refresh($_CONF['site_url'] . "/comment.php?sid=$comment_id&amp;pid=$pid&amp;type=$type");
        exit;

    } else {
        $media_title = DB_getItem($_TABLES['mg_media'],'media_title',"media_id='" . $comment_id . "'");
        if (SEC_hasRights('mediagallery.admin') ) {
            $commentdelete = true;
        }
        $display = COM_siteHeader();
        $display .= plugin_commentparent_mediagallery($comment_id);
        $display .= COM_userComments($comment_id, $media_title, $type, $order, $commentmode,0,1,false,$commentdelete);
        $display .= COM_siteFooter();
    }

    return $display;
}

/**
* Check to see if this Plugin uses comments
*
* @return   boolean true or false
*
*/
function plugin_commentsupport_mediagallery()
{
    return true;
}

// GL 1.3 or less
function plugin_handlecomment_mediagallery($id, $operation) {
    global $_CONF, $_MG_CONF, $_TABLES;

    $media_id = DB_getItem($_TABLES['comments'], 'sid', 'cid=' . $id);

    if ($operation == 'delete') {
        if (!SEC_hasRights('mediagallery.admin')) {
            COM_errorLOG("Unprivileged user tried to delete a comment.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR", 1);
        } else {
            DB_delete($_TABLES['comments'], 'cid', $id);
        }
    }

    $commentCount = DB_count($_TABLES['comments'], 'sid', $media_id);
    DB_change($_TABLES['mg_media'],'media_comments',$commentCount,'media_id',$media_id);

    // Now redirect the program flow to the view of the file and its comments
    echo COM_refresh($_MG_CONF['site_url'] . '/media.php?s=' . $media_id);

    exit;
}

// GL 1.3
function plugin_commentparent_mediagallery($id) {
    global $_CONF, $_MG_CONF;

    require_once($_MG_CONF['path_html'] . '/classAlbum.php');
    require_once($_MG_CONF['path_html'] . '/lib-media.php');
    list($ptitle, $retval) = MG_displayMediaImage($id,0,0,0);
    return $retval;

}

/** GL 1.4
 * Plugin function that is called after comment form is submitted.
 * Needs to at least save the comment and check return value.
 * Add any additional logic your plugin may need to perform on comments.
 *
 * $title       comment title
 * $comment     comment text
 * $id          Item id to which $cid belongs
 * $pid         comment parent
 * $postmode    'html' or 'text'
 *
 */
function plugin_savecomment_mediagallery($title,$comment,$id,$pid,$postmode) {
    global $_CONF, $_MG_CONF, $_TABLES, $LANG03;

    $title = strip_tags ($title);
    $pid = COM_applyFilter ($pid, true);
    $postmode = COM_applyFilter ($postmode);

    $ret = CMT_saveComment ( $title, $comment, $id, $pid, 'mediagallery',$postmode);

    if ( $ret > 0 ) {
        return COM_siteHeader() . CMT_commentform ($title, $comment, $id, $pid, 'mediagallery', $LANG03[14], $postmode) . COM_siteFooter();
    } else {
        $comments = DB_count ($_TABLES['comments'], array('sid','type'), array($id, 'mediagallery'));
        DB_change($_TABLES['mg_media'],'media_comments', $comments, 'media_id',$id);
        return (COM_refresh ($_MG_CONF['site_url'] . "/media.php?s=$id") );
    }
}

/** GL 1.4
 * Plugin function to delete a comment
 * $cid    Comment to be deleted
 * $id     Item id to which $cid belongs
 *
 */
function plugin_deletecomment_mediagallery($cid,$id) {
    global $_CONF, $_MG_CONF, $_TABLES;

    // find the album that holds this peice of media

    $sql = "SELECT * FROM {$_TABLES['mg_media_albums']} WHERE media_id='" . $id . "'";
    $result = DB_query($sql);
    $nRows  = DB_numRows($result);
    if ( $nRows > 0 ) {
        $row = DB_fetchArray($result);
        $sql = "SELECT group_id,perm_owner,perm_group,perm_members,perm_anon FROM {$_TABLES['mg_albums']} WHERE album_id=" . $row['album_id'];
        $result = DB_query($sql);
        $nRows = DB_numRows($result);
        if ( $nRows > 0 ) {
            $row = DB_fetchArray($result);
            $access = SEC_hasAccess ($row['owner_id'],
                        $row['group_id'],
                        $row['perm_owner'],
                        $row['perm_group'],
                        $row['perm_members'],
                        $row['perm_anon']);
        } else {
            $access = 0;
        }
    } else {
        $access = 0;
    }

    if ($access == 3 || SEC_hasRights('mediagallery.admin')){
        if (CMT_deleteComment($cid, $id, 'mediagallery') == 0) {
            //reduce count in media table
            $comments = DB_count ($_TABLES['comments'], array('sid','type'), array($id, 'mediagallery'));
            DB_change($_TABLES['mg_media'],'media_comments', $comments, 'media_id', $id);
            // Now redirect the program flow to the view of the file and its comments
            return (COM_refresh($_MG_CONF['site_url'] . "/media.php?s=$id"));

        } else {
            return false;
        }
    } else {
        return false;
    }
}

function plugin_getcommenturlid_mediagallery( ) {
    global $_CONF, $_MG_CONF;
    $retval = array();
    $retval[] = $_MG_CONF['site_url'] . '/media.php';
    $retval[] = 's';
    return $retval;
}

/** GL 1.4
 * Plugin function to display a specific comment thread
 * $id      Unique idenifier for item comment belongs to
 * $cid     Comment id to display (possibly including sub-comments)
 * $title   Page/comment title
 * $order   'ASC' or 'DSC' or blank
 * $format  'threaded', 'nested', or 'flat'
 * $page    Page number of comments to display
 * $view    True to view comment (by cid), false to display (by $pid)
 */
function plugin_displaycomment_mediagallery($id,$commentid,$title,$order,$format,$page,$view) {
    global $_CONF, $_USER, $_MG_CONF, $LANG_LOGIN;

    if ( $_USER['uid'] < 2 && $_MG_CONF['loginrequired'] == 1) {
        $display = MG_siteHeader();
        $display .= COM_startBlock ($LANG_LOGIN[1], '',
                  COM_getBlockTemplate ('_msg_block', 'header'));
        $login = new Template($_CONF['path_layout'] . 'submit');
        $login->set_file (array ('login'=>'submitloginrequired.thtml'));
        $login->set_var ('login_message', $LANG_LOGIN[2]);
        $login->set_var ('site_url', $_CONF['site_url']);
        $login->set_var ('lang_login', $LANG_LOGIN[3]);
        $login->set_var ('lang_newuser', $LANG_LOGIN[4]);
        $login->parse ('output', 'login');
        $display .= $login->finish ($login->get_var('output'));
        $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
        $display .= MG_siteFooter();
        echo $display;
        exit;
    }

    $retval = '';
    require_once($_MG_CONF['path_html'] . 'classAlbum.php');
    require_once($_MG_CONF['path_html'] . 'lib-media.php');
    list($ptitle,$retval) =  MG_displayMediaImage( $id, 0, 0, 0 );
    if (SEC_hasRights('mediagallery.admin')){
        $delete_option = true;
    } else
        $delete_option = false;

    if ($view == 1) {
        $retval .= CMT_userComments ($id, $title, 'mediagallery',$order,$format,$commentid,$page,true,$delete_option);
    } else {
        $retval .= CMT_userComments ($id, $title, 'mediagallery',$order,$format,$commentid,$page,false,$delete_option);
    }
    return $retval;
}


/**
* Returns the items for this plugin that should appear on the main menu
*
* NOTE: this MUST return the url/value pairs in the following format
* $<arrayname>[<label>] = <url>
*
* Universal Plugin:  Uncomment and fill in variables;
*
* @return    array   Associative array of menu items to be added to menu
*
*/

function plugin_getmenuitems_mediagallery() {
    global $_CONF, $_USER, $_MG_CONF;

    $menulabel = $_MG_CONF['menulabel'];
    $menurul   = $_MG_CONF['site_url'] . "/index.php";     // Menu url here

    $menuitems = array();
    $menuitems["$menulabel"] = $menurul;
    return $menuitems;
}

function plugin_getheadercode_mediagallery() {
    global $_CONF, $_MG_CONF, $mgLightBox, $glversion,$swfjsinclude;

    $mg_header = '';

    if ( $glversion[1] < 4 ) {
        $mg_header = '<link rel="stylesheet" type="text/css" href="' . $_MG_CONF['site_url'] . '/gl13compat.css">';
    }
    $mg_header .= "<link rel=\"stylesheet\" type=\"text/css\" href=\"" . $_MG_CONF['site_url'] . "/mediagallery.css?ver=5\">" . LB;
    $mg_header .= '<script type="text/javascript" src="' . $_MG_CONF['site_url'] . '/js/swfobject.js"></script>' . LB;
    $mg_header .= '<script type="text/javascript">var mgBaseURL = \'' . $_MG_CONF['site_url'] . '\'</script>' . LB;
    $mg_header .= '<script type="text/javascript" src="' . $_MG_CONF['site_url'] . '/js/mediagallery.js"></script>' . LB;
    if ( $mgLightBox ) {
        $mg_header .= '<script type="text/javascript" src="' . $_MG_CONF['site_url'] . '/js/mootools.js?ver=1"></script>' . LB;
        $mg_header .= '<script type="text/javascript" src="' . $_MG_CONF['site_url'] . '/js/slimbox.js?ver=1"></script>' . LB;
    }
    $swfjsinclude = 1;

    return $mg_header;
}

/**
  * Whats New Block API Support
  * Return the Headline and Byline for the new section in the Whatsnew Block
*/
function plugin_whatsnewsupported_mediagallery() {
    global $_CONF, $_MG_CONF, $LANG_MG00,$mg_installed_version;


    if ( $_MG_CONF['whatsnew'] == 0 ) {
        return '';
    }

    if ( $mg_installed_version != $_MG_CONF['version'] ) {
        return '';
    }

    $label = sprintf($LANG_MG00['whatsnew_prompt'],$_MG_CONF['whatsnew_time']);

    return array($LANG_MG00['whatsnew_title'],$label);
}
/**
  * API function provides the content of our "What's New" feed
*/
function plugin_getwhatsnew_mediagallery() {
    global $MG_albums, $_TABLES, $_CONF, $_MG_CONF, $_USER, $LANG_MG03, $glversion,$mg_installed_version;

    if ($_MG_CONF['whatsnew'] == 0 ) {
        return;
    }

    if ( $mg_installed_version != $_MG_CONF['version'] ) {
        return;
    }

    $newMediaCount    = 0;
    $newCommentCount = 0;

    $items = array();

    $newAge = time() - ($_MG_CONF['whatsnew_time'] * 86400);

    $sql = "SELECT album_id FROM {$_TABLES['mg_albums']} WHERE last_update >= " . $newAge . " ORDER BY last_update DESC";
    $result = DB_query($sql,1);
    while ($row = DB_fetchArray($result)) {
        $aid = $row['album_id'];

        if ( $MG_albums[$aid]->access > 0 && $MG_albums[$aid]->hidden != 1 ) {
            $title = $MG_albums[$aid]->title;
            if ( strlen($title) > $_MG_CONF['title_length'] ) {
                $dTitle = substr($title,0,$_MG_CONF['title_length'] - 3) . '...';
            } else {
                $dTitle = $title;
            }
            $items[] = '<a href="' . $_MG_CONF['site_url'] . '/album.php?aid=' . $aid . '">' . $dTitle . '</a>';
            $newMediaCount++;
        }

    }
    if ( $newMediaCount == 0 ) {
        $retval .= $LANG_MG03['no_new_items'] . '<br>' . LB;
    }
    if ( $_MG_CONF['disable_whatsnew_comments'] == 0 ) {
         $sql = "SELECT * FROM {$_TABLES['comments']} AS c LEFT JOIN {$_TABLES['mg_media_albums']} AS ma ON c.sid=ma.media_id LEFT JOIN {$_TABLES['mg_albums']} AS a ON ma.album_id=a.album_id WHERE c.date >=  DATE_SUB(NOW(), INTERVAL " . $_MG_CONF['whatsnew_time'] . " DAY ) AND c.type='mediagallery' GROUP BY c.sid ORDER BY c.date DESC LIMIT 15";

        $result = DB_query( $sql,1);
        $nrows2 = DB_numRows( $result );
        if( $nrows2 == 0 ) {
            $retval .= '' . '<br>' . LB;
        } else {
            while ($A = DB_fetchArray($result)) {
                $access = SEC_hasAccess ($A['owner_id'],
                                         $A['group_id'],
                                         $A['perm_owner'],
                                         $A['perm_group'],
                                         $A['perm_members'],
                                         $A['perm_anon']);
                if ( $access > 0 ) {
                    $titleLength = $_MG_CONF['title_length'];        // Compensate for the added HTML
                    $title = "<b>C:</b>&nbsp;".$A['title'];
                     if ( $glversion[1] < 4 ) {
                        $str = "<a href=\"{$_CONF['site_url']}/comment.php?type=mediagallery&amp;cid={$A['sid']}\">";
                    } else {
                        $str = "<a href=\"{$_CONF['site_url']}/comment.php?mode=view&amp;cid={$A['cid']}&amp;sid={$A['sid']}&amp;type=mediagallery\">";
                    }
                    $str .= substr($title,0,$titleLength);
                    $str .= '</a>';
                    $items[] = $str;
                    $newCommentCount++;
                }
            }
        }
        if ( $newCommentCount == 0 ) {
            $retval .= $LANG_MG03['no_comments'] . '<br>' . LB;
        }
    }
    if ( $newMediaCount == 0 && $newCommentCount == 0 ) {
        return $retval;
    } else {
        return $items;
    }
}

/**
* Shows the statistics for the plugin on stats.php.  If
* $showsitestats is 1 then we are to only print the overall stats in the 'site
* statistics' box otherwise we show the detailed stats for the plugin
*
* Universal Plugin:  Modify/uncomment use it
*
* @param    int showsitestate   Flag to let us know which stats to get
* @return   string  returns formatted HTML to insert in stats page
*
*/
function plugin_showstats_mediagallery($showsitestats) {
    global $_CONF, $_MG_CONF, $_TABLES, $LANG_MG00, $MG_albums, $_USER, $glversion;

    if ($_USER['uid'] < 2 && $_MG_CONF['loginrequired'] == 1) {
        return;
    }
    $previd = -1;
    $loopcounter = 0;

    $retval='';
    if ($showsitestats == 1) {
        // This shows in the summary box
        $total_pages=DB_count($_TABLES['mg_media']);
        $summary_label = $LANG_MG00['items_in'] . ' ' .  $LANG_MG00['plugin'];

        $retval = "<table border = '0' width='100%' cellspacing='0' cellpadding='0'>";
        $retval .= "<tr><td>$summary_label</td>";
        $retval .= "<td align='right'>" . $total_pages . "&nbsp;&nbsp </td></tr></table>";
    } else {
        if ( $glversion[1] < 4 ) {
            // show top rated items first...
            $sql = "SELECT * FROM {$_TABLES['mg_albums']} as a LEFT JOIN {$_TABLES['mg_media_albums']} as ma
                    on a.album_id=ma.album_id LEFT JOIN {$_TABLES['mg_media']} as m on ma.media_id=m.media_id WHERE
                    m.media_rating <> 0 AND a.hidden=0 " . COM_getPermSQL('and') . " ORDER BY m.media_rating DESC LIMIT 10";

            $result = DB_query($sql);
            $numrows = DB_numRows($result);
            $retval .= COM_startBlock($LANG_MG00['stats_rate_title']);
            if ($numrows > 0) {
                $stat_templates = new Template($_CONF['path_layout'] . 'stats');
                $stat_templates->set_file(array(
                    'itemstats' =>'itemstatistics.thtml',
                    'statrow'   =>'singlestat.thtml'
                ));
                $stat_templates->set_var('item_label', $LANG_MG00['media_col_header']);
                $stat_templates->set_var('stat_name', $LANG_MG00['rating']);
                while ($A = DB_fetchArray($result)) {
                    $stat_templates->set_var('item_url', $_MG_CONF['site_url'] . '/media.php?s=' . $A['media_id']);

                    if (empty($A['media_title'])){
                        $title = $LANG_MG00['album'] . ' ' . strip_tags($A['album_title']) . ' - ' . $LANG_MG00['no_title'];
                    } else {
                         $title = strip_tags($A['media_title']);
                    }
                    $stat_templates->set_var('item_text', $title);
                    $stat_templates->set_var('item_stat', $A['media_rating'] . '/10.00');
                    $stat_templates->parse('stat_row','statrow',true);
                }
                $stat_templates->parse('output','itemstats', true);
                $retval .= $stat_templates->finish($stat_templates->get_var('output'));

            } else {
                $retval .= $LANG_MG00['none_rated'];
            }
            $retval .= COM_endBlock();
        } else { // Geeklog v1.4+
            $header_arr = array(
                array('text' => $LANG_MG00['media_col_header'], 'field' => 'title','header_class' => 'stats-header-title'),
                array('text' => $LANG_MG00['rating'], 'field' => 'rating','field_class' => 'stats-list-count'),
            );
            $data_arr = array();
            $text_arr = array('has_menu'     => false,
                              'title'        => $LANG_MG00['stats_rate_title'],
            );
            $sql = "SELECT a.album_id,m.media_original_filename,m.media_title,m.media_id,m.media_rating FROM {$_TABLES['mg_albums']} as a LEFT JOIN {$_TABLES['mg_media_albums']} as ma
                    on a.album_id=ma.album_id LEFT JOIN {$_TABLES['mg_media']} as m on ma.media_id=m.media_id WHERE
                    m.media_rating <> 0 AND a.hidden=0 " . COM_getPermSQL('and') . " ORDER BY m.media_rating DESC LIMIT 10";

            $result = DB_query($sql);
            $numrows = DB_numRows($result);
            if ($numrows > 0) {
                for ($i = 0; $i < $numrows && $i < 10; $i++) {
                    $A = DB_fetchArray($result);
                    $aid = $A['album_id'];
                    if ( $A['media_title'] == '' || $A['media_title'] == " ") {
                        if ( $A['media_original_filename'] == '' ) {
                            $title = '<b>' . $LANG_MG00['album'] . '</b>' . '<em>' . strip_tags($MG_albums[$aid]->title) . ' - ' . $LANG_MG00['no_title'] . '</em>';
                        } else {
                            $title = $A['media_original_filename'];
                        }
                    } else {
                         $title = strip_tags($A['media_title']);
                    }

                    $S['title'] = '<a href="' . $_MG_CONF['site_url'] . '/media.php?s=' . $A['media_id'] . '">' . $title . '</a>';
                    $S['rating']  = $A['media_rating'] . '/10.00';
                    $data_arr[$i] = $S;
                }
                $retval .= ADMIN_simpleList("", $header_arr, $text_arr, $data_arr);
            }
        }

        if ( $glversion[1] < 4 ) {
            $stat_templates = new Template($_CONF['path_layout'] . 'stats');
            $stat_templates->set_file(array('itemstats'=>'itemstatistics.thtml',
                                    'statrow'=>'singlestat.thtml'));

            // This fills the top the box  Use the following as a template
            $sql    =  "SELECT DISTINCT m.media_id,m.media_title,m.media_views,ma.album_id
                        FROM " . $_TABLES['mg_media'] . " as m" .
                        " LEFT JOIN " . $_TABLES['mg_media_albums'] . " as ma" .
                        " ON m.media_id=ma.media_id " .
                        " WHERE m.media_views > 0 " .
                        " ORDER BY m.media_views DESC LIMIT 10";
            $result = DB_query($sql);
            $nrows  = DB_numRows($result);
            $retval .= COM_startBlock($LANG_MG00['stats_title']);
            if ($nrows > 0) {
                $stat_templates->set_var('item_label',$LANG_MG00['media_col_header']);
                $stat_templates->set_var('stat_name',$LANG_MG00['hitsmsg']);
                while ($A = DB_fetchArray($result)) {
                    if ( $A['media_id'] == $previd )
                        continue;
                    $previd = $A['media_id'];
                    if ( $A['media_id'] != '' ) {
                        $loopcounter++;
                        $stat_templates->set_var('item_url', $_MG_CONF['site_url'] . '/media.php?s=' . $A['media_id']);
                        if (empty($A['media_title'])){
                            $title = $LANG_MG00['album'] . ' ' . strip_tags($MG_albums[$A['album_id']]->title) . ' - ' . $LANG_MG00['no_title'];
                        } else {
                             $title = strip_tags($A['media_title']);
                        }
                        $stat_templates->set_var('item_text', $title . '&nbsp;');
                        $stat_templates->set_var('item_stat', $A['media_views']);
                        $stat_templates->parse('stat_row','statrow',true);
                    }
                    if ( $loopcounter > 10 )
                        break;
                }
                $stat_templates->parse('output','itemstats');
                $retval .= $stat_templates->finish($stat_templates->get_var('output'));
            } else {
                $retval .= $LANG_MG00['no_viewed_items'];
            }
            $retval .= COM_endBlock();
        } else {
            // gl 1.4+
            $loopcounter = 0;
            $previd = '';

            $header_arr = array(
                array('text' => $LANG_MG00['media_col_header'], 'field' => 'title','header_class' => 'stats-header-title'),
                array('text' => $LANG_MG00['hitsmsg'], 'field' => 'views','field_class' => 'stats-list-count'),
            );
            $data_arr = array();
            $text_arr = array('has_menu'     => false,
                              'title'        => $LANG_MG00['stats_title'],
            );
            $sql    =  "SELECT DISTINCT m.media_id,m.media_title,ma.album_id,m.media_original_filename,m.media_views
                        FROM " . $_TABLES['mg_media'] . " as m" .
                        " LEFT JOIN " . $_TABLES['mg_media_albums'] . " as ma" .
                        " ON m.media_id=ma.media_id " .
                        " WHERE m.media_views > 0 " .
                        " ORDER BY m.media_views DESC LIMIT 10";
            $result  = DB_query($sql);
            $numrows = DB_numRows($result);
            if ($numrows > 0) {
                for ($i = 0; $i < $numrows; $i++) {
                    $A = DB_fetchArray($result);
                    if ( $A['media_id'] == $previd )
                        continue;
                    $aid = $A['album_id'];
                    $previd = $A['media_id'];
                    if ( $A['media_id'] != '' && $MG_albums[$aid]->access > 0 ) {
                        $loopcounter++;

                        if ( $A['media_title'] == '' || $A['media_title'] == " ") {
                            if ( $A['media_original_filename'] == '' ) {
                                $title = '<b>' . $LANG_MG00['album'] . '</b>' . '<em>' . strip_tags($MG_albums[$aid]->title) . ' - ' . $LANG_MG00['no_title'] . '</em>';
                            } else {
                                $title = $A['media_original_filename'];
                            }
                        } else {
                             $title = strip_tags($A['media_title']);
                        }
                        $S['title'] = '<a href="' . $_MG_CONF['site_url'] . '/media.php?s=' . $A['media_id'] . '">' . $title . '</a>';
                        $S['views']  = $A['media_views'];
                        $data_arr[$loopcounter] = $S;
                    }
                    if ( $loopcounter > 10 )
                        break;
                }
                $retval .= ADMIN_simpleList("", $header_arr, $text_arr, $data_arr);
            }
        }
    }
    return $retval;
}

function plugin_statssummary_mediagallery() {
    global $_CONF, $_MG_CONF, $_TABLES, $LANG_MG00, $_USER;

    if ( $_USER['uid'] < 2 && $_MG_CONF['loginrequired'] == 1) {
        return;
    }

    // This shows in the summary box
    $total_items=DB_count($_TABLES['mg_media']);
    $summary_label = $LANG_MG00['items_in'] . ' ' .  $LANG_MG00['plugin'];
    $retval[] = $summary_label;
    $retval[] = $total_items;
    return $retval;
}



/**
* This will put an option for the plugin in the command and control block on moderation.php
*
* Add the plugin name, icon and link to the command and control block in moderation.php
*
* @return   array   Array containing (plugin name, admin url, url of plugin icon)
*
*/

function plugin_cclabel_mediagallery() {
    global $_CONF, $_MG_CONF, $LANG_MG00;

    if (SEC_hasRights('mediagallery.config') ) {
        return array($LANG_MG00['plugin'],
            $_MG_CONF['admin_url'] . 'index.php',
            $_MG_CONF['site_url'] . '/images/mediagallery.gif');
    } else {
        return '';
    }
}

/**
* Returns the administrative option for this plugin
*
* Adds the plugin to the Admin menu
*
* Universal Plugin:  Modify/Uncomment use it
*
* @return   array   Array containing (plugin name, plugin admin url, # of items in plugin or '')
*
*/
function plugin_getadminoption_mediagallery() {
    global $_CONF, $_TABLES, $LANG_MG00, $_MG_CONF;

    if (SEC_hasRights('mediagallery.config')) {
        return array($LANG_MG00['plugin'], $_MG_CONF['admin_url'] . 'index.php', DB_count($_TABLES['mg_albums']));
    }
}


function plugin_autotags_mediagallery ($op, $content = '', $autotag = '') {
    global $MG_albums, $_MG_CONF, $_CONF, $_MG_USERPREFS, $_TABLES, $LANG_MG00, $LANG_MG03, $side_count, $ss_count, $swfjsinclude;
    global $mgAutoTagArray, $mg_installed_version;

    if ( $mg_installed_version != $_MG_CONF['version'] ) {
        return $content;
    }

    if ($op == 'tagname' ) {
        return array('album','media','img','slideshow','fslideshow','video','audio','download','image','oimage','mlink');
    } else if ($op == 'parse') {

        $T = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
        // see if we have an alignment option included
        $caption = $autotag['parm2'];
        $aSet = 0;
        $skip = 0;

        // default values for parameters
        $border         = $_MG_CONF['at_border'];
        $align          = $_MG_CONF['at_align'];
        $width          = $_MG_CONF['at_width'];
        $height         = $_MG_CONF['at_height'];
        $src            = $_MG_CONF['at_src'];
        $autoplay       = $_MG_CONF['at_autoplay'];
        $enable_link    = $_MG_CONF['at_enable_link'];
        $delay          = $_MG_CONF['at_delay'];
        $transition     = $_MG_CONF['at_transition'];
        $showtitle      = $_MG_CONF['at_showtitle'];
        $destination    = 'content';
        $linkID         = 0;
        $alt            = 0;

        if ( $align != '' ) {
            $aSet = 1;
        }

        // parameter processing - logic borrowed from
        // Dirk Haun's Flickr plugin

        $px = explode (' ', trim ($autotag['parm2']));
        if (is_array ($px)) {
            foreach ($px as $part) {
                if (substr ($part, 0, 6) == 'width:') {
                    $a = explode (':', $part);
                    $width = $a[1];
                    $skip++;
                } elseif (substr ($part, 0, 7) == 'height:') {
                    $a = explode (':', $part);
                    $height = $a[1];
                    $skip++;
                } elseif (substr ($part, 0, 7) == 'border:') {
                    $a = explode (':', $part);
                    $border = $a[1];
                    $skip++;
                } elseif (substr ($part,0, 6) == 'align:') {
                    $a = explode(':', $part);
                    $align = $a[1];
                    $skip++;
                    $aSet = 1;
                } elseif (substr($part,0,4) == 'src:') {
                    $a = explode(':', $part);
                    $src = $a[1];
                    $skip++;
                } elseif (substr($part,0,9) == 'autoplay:') {
                    $a = explode(':', $part);
                    $autoplay = $a[1];
                    $skip++;
                } elseif (substr($part,0,5) == 'link:') {
                    $a = explode(':',$part);
                    $enable_link = $a[1];
                    $skip++;
                } elseif (substr ($part, 0, 6) == 'delay:') {
                    $a = explode (':', $part);
                    $delay = $a[1];
                    $skip++;
                } elseif (substr ($part, 0, 11) == 'transition:') {
                    $a = explode (':', $part);
                    $transition = $a[1];
                    $skip++;
                } elseif (substr ($part,0, 6) == 'title:' ) {
                    $a = explode (':',$part);
                    $showtitle = $a[1];
                    $skip++;
                } elseif (substr ($part, 0, 5) == 'dest:') {
                    $a = explode (':', $part);
                    $destination = $a[1];
                    $skip++;
                    if ( $destination != 'content' && $destination != 'block' ) {
                        $destination = 'content';
                    }
                } elseif ( substr($part,0,7) == 'linkid:' ) {
                    $a = explode (':',$part);
                    $linkID = $a[1];
                    $skip++;
                } elseif ( substr($part,0,4) == 'alt:' ) {
                    $a = explode (':',$part);
                    $alt = $a[1];
                    $skip++;
                } else {
                    break;
                }
            }
            if ($skip != 0) {
                if (count ($px) > $skip) {
                    for ($i = 0; $i < $skip; $i++) {
                        array_shift ($px);
                    }
                    $caption = trim (implode (' ', $px));
                } else {
                    $caption = '';
                }
            }
        } else {
            $caption = trim ($autotag['parm2']);
        }

        if ( !is_numeric($autotag['parm1'][0]) ) {
            switch ($autotag['parm1'][0] ) {
                case 'n' :
                    $align = '';
                    $aSet = 1;
                    break;
                case 'c' :
                    $align="center";
                    $aSet = 1;
                    break;
                case 'l' :
                    $align = "left";
                    $aSet = 1;
                    break;
                case 'r' :
                    $align = "right";
                    $aSet = 1;
                    break;
                case 'a' :
                    $align=(!($side_count % 2) ? "left" : "right" );
                    $side_count++;
                    $aSet = 1;
                    break;
                default :
                    $align=(!($side_count % 2) ? "left" : "right" );
                    $side_count++;
                    break;
            }
            $parm1 = COM_applyFilter(substr($autotag['parm1'],1,strlen($autotag['parm1'])-1));
        } else {
            $parm1 = COM_applyFilter($autotag['parm1']);
            if ( $aSet == 0 || $align == 'auto') {
                $align=(!($side_count % 2) ? "left" : "right" );
                $side_count++;
            }
        }
        if ( $align == 'none' ) {
            $align = '';
        }
        // sanity check incase the album has been deleted or something...
        if ( $autotag['tag'] != 'media' && $autotag['tag'] != 'image' && $autotag['tag'] != 'video' && $autotag['tag'] != 'audio' && $autotag['tag'] != 'download' && $autotag['tag'] != 'oimage' && $autotag['tag'] != 'img' && $autotag['tag'] != 'mlink') {
            if ( !isset($MG_albums[$parm1]) ) {
                return $content;
            }
        }

        switch( $autotag['tag'] ) {
            case 'download' :
                $side_count--;
                $sql = "SELECT ma.album_id FROM {$_TABLES['mg_media']} AS m LEFT JOIN {$_TABLES['mg_media_albums']} AS ma ON m.media_id=ma.media_id WHERE m.media_id='" . addslashes($parm1) . "'";
                $result = DB_query($sql);
                if ( DB_numRows($result) > 0 ) {
                    $row = DB_fetchArray($result);
                    $aid = $row['album_id'];
                    if ( $MG_albums[$aid]->access == 0 ) {
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                        return $content;
                    }
                    $link = '<a href="' . $_MG_CONF['site_url'] . '/download.php?mid=' . $parm1 . '">';
                    if ( $caption != "" ) {
                        $link .= $caption;
                    } else {
                        $link .= 'download';
                    }
                    $link .= '</a>';
                    if ( $destination != 'block' ) {
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    } else {
                        $autoTagCount = $mgAutoTagArray['count'];
                        $mgAutoTagArray['tags'][$autoTagCount] = $link;
                        $mgAutoTagArray['count']++;
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    }
                    return $content;
                } else {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }
                break;
            case 'mlink' :
                $side_count--;
                $sql = "SELECT m.remote_url,ma.album_id FROM {$_TABLES['mg_media']} AS m LEFT JOIN {$_TABLES['mg_media_albums']} AS ma ON m.media_id=ma.media_id WHERE m.media_id='" . addslashes($parm1) . "'";
                $result = DB_query($sql);
                if ( DB_numRows($result) > 0 ) {
                    $row = DB_fetchArray($result);
                    $aid = $row['album_id'];
                    if ( $MG_albums[$aid]->access == 0 ) {
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                        return $content;
                    }
                    if ( $alt == 1 && $row['remote_url'] != '' ) {
                        $link = '<a href="' . $row['remote_url'] . '">';
                    } else {
                        $link = '<a href="' . $_MG_CONF['site_url'] . '/media.php?f=0&amp;sort=0&amp;s=' . $parm1 . '">';
                    }
                    if ( $caption != "" ) {
                        $link .= $caption;
                    } else {
                        $link .= $LANG_MG03['click_here'];
                    }
                    $link .= '</a>';
                    if ( $destination != 'block' ) {
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    } else {
                        $autoTagCount = $mgAutoTagArray['count'];
                        $mgAutoTagArray['tags'][$autoTagCount] = $link;
                        $mgAutoTagArray['count']++;
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    }
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                } else {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }
                break;
            case 'video' :
                $sql = "SELECT ma.album_id,m.media_id,m.mime_type,m.remote_url,m.media_filename,m.media_mime_ext,m.media_original_filename,m.media_tn_attached,m.media_resolution_x,m.media_resolution_y,m.remote_media FROM {$_TABLES['mg_media']} AS m LEFT JOIN {$_TABLES['mg_media_albums']} AS ma ON m.media_id=ma.media_id WHERE m.media_id='" . addslashes($parm1) . "'";
                $result = DB_query($sql);
                if ( DB_numRows($result) > 0 ) {
                    $row = DB_fetchArray($result);
                    $aid = $row['album_id'];
                    if ( $MG_albums[$aid]->access == 0 ) {
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                        return $content;
                    }
                    // determine height / width and aspect
                    if ( $width == 'auto' && $row['media_resolution_x'] > 0 && $row['media_resolution_y'] > 0 ) {
                        $videoheight = $row['media_resolution_y'];
                        $videowidth  = $row['media_resolution_x'];
                    } else {
                        if ( $row['media_resolution_x'] > 0 && $row['media_resolution_y'] > 0 ) {
                            if ( $row['media_resolution_x'] >= $row['media_resolution_y'] ) {
                                // landscape
                                $ratio = $row['media_resolution_y'] / $row['media_resolution_x'];
                                $orientation = 0;
                            } else {
                                // portrait
                                $ratio = $row['media_resolution_x'] / $row['media_resolution_y'];
                                $orientation = 1;
                            }
                        } else {
                            $ratio =  0.75;
                            $orientation = 0;
                        }
                        if ( $orientation == 0 ) {
                            if ( $width > 0 && $height == 0 ) {
                                $videoheight = round($width * $ratio);
                                $videowidth  = $width;
                            } else if ( $width == 0 && $height == 0 ) {
                                $videoheight = 200 * $ratio;
                                $videowidth  = 200;
                            } else if ( $width == 0 && $height > 0 ) {
                                $videowidth = round($height / $ratio);
                                $videoheidht = $height;
                            }
                        } else {
                            if ( $width > 0 && $height == 0 ) {
                                $videoheight = round($width / $ratio);
                                $videowidth  = $width;
                            } else if ( $width == 0 && $height == 0 ) {
                                $videoheight = 200;
                                $videowidth  = round(200 / $ratio);
                            } else if ( $width == 0 && $height > 0 ) {
                                $videowidth = round($height * $ratio);
                                $videoheidht = $height;
                            }
                        }
                    }
                    switch( $row['mime_type'] ) {
                        case 'embed' :
                            if ( $align == 'left' || $align == 'right' ) {
                                $float = 'float:' . $align . ';';
                            } else {
                                $float = '';
                            }
                            $link = '<div style="' . $float . 'padding:5px;">' .
                                    $row['remote_url'] .
                                    '</div>';
                            if ( $destination != 'block' ) {
                                $content = str_replace ($autotag['tagstr'], $link, $content);
                            } else {
                                $autoTagCount = $mgAutoTagArray['count'];
                                $mgAutoTagArray['tags'][$autoTagCount] = $link;
                                $mgAutoTagArray['count']++;
                                $link = '';
                                $content = str_replace ($autotag['tagstr'], $link, $content);
                            }
                            return $content;
                            break;
                        case 'video/x-ms-asf' :
                        case 'video/x-ms-asf-plugin' :
                        case 'video/avi' :
                        case 'video/msvideo' :
                        case 'video/x-msvideo' :
                        case 'video/avs-video' :
                        case 'video/x-ms-wmv' :
                        case 'video/x-ms-wvx' :
                        case 'video/x-ms-wm' :
                        case 'application/x-troff-msvideo' :
                        case 'application/x-ms-wmz' :
                        case 'application/x-ms-wmd' :
                            $V = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                            $V->set_file (array ('video' => 'view_asf.thtml'));
                            $V->set_var(array(
                                'autostart'         => $autoplay ? 'true' : 'false',
                                'enablecontextmenu' => 'true',
                                'stretchtofit'      => 'false',
                                'showstatusbar'     => 'false',
                                'showcontrols'      => 'true',
                                'showdisplay'       => 'false',
                                'height'            => $videoheight,
                                'width'             => $videowidth,
                                'bgcolor'           => '#FFFFFF',
                                'playcount'         => '9999',
                                'loop'              => 'true',
                                'movie'             => $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'],
                                'autostart0'         => $autoplay ? '1' : '0',
                                'enablecontextmenu0' => '1',
                                'stretchtofit0'      => '0',
                                'showstatusbar0'     => '0',
                                'uimode0'            => 'none',
                                'showcontrols0'      => '1',
                                'showdisplay0'      => '0',
                            ));
                            $V->parse('output','video');
                            if ( $align != '' && $align != "center") {
                                $u_image = '<div style="float:' . $align . ';padding:5px;">' . $V->finish($V->get_var('output')) . '</div>';
                            } else {
                                $u_image = '<div style="padding:5px;">' . $V->finish($V->get_var('output')) . '</div>';
                            }
                            break;
                        case 'video/mpeg' :
                        case 'video/x-motion-jpeg' :
                        case 'video/quicktime' :
                        case 'video/mpeg' :
                        case 'video/x-mpeg' :
                        case 'video/x-mpeq2a' :
                        case 'video/x-qtc' :
                            $V = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                            $V->set_file (array ('video' => 'view_quicktime.thtml'));
                            $V->set_var(array(
                                'autoref'       => 'true',
                                'autoplay'      => $autoplay ? 'true' : 'false',
                                'controller'    => 'true',
                                'kioskmode'     => 'true',
                                'scale'         => 'aspect',
                                'height'        => $videoheight,
                                'width'         => $videowidth,
                                'bgcolor'       => '#F0F0F0',
                                'loop'          => 'true',
                                'movie'         => $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'],
                            ));
                            $V->parse('output','video');
                            if ( $align != '' && $align != "center" ) {
                                $u_image = '<div style="float:' . $align . ';padding:5px;">' . $V->finish($V->get_var('output')) . '</div>';
                            } else {
                                $u_image = '<div style="padding:5px;">' . $V->finish($V->get_var('output')) . '</div>';
                            }
                            break;
                        case 'application/x-shockwave-flash' :
                            // set the default playback options...
                            $playback_options['play']    = $_MG_CONF['swf_play'];
                            $playback_options['menu']    = $_MG_CONF['swf_menu'];
                            $playback_options['quality'] = $_MG_CONF['swf_quality'];
                            $playback_options['height']  = $_MG_CONF['swf_height'];
                            $playback_options['width']   = $_MG_CONF['swf_width'];
                            $playback_options['loop']    = $_MG_CONF['swf_loop'];
                            $playback_options['scale']   = $_MG_CONF['swf_scale'];
                            $playback_options['wmode']   = $_MG_CONF['swf_wmode'];
                            $playback_options['allowscriptaccess'] = $_MG_CONF['swf_allowscriptaccess'];
                            $playback_options['bgcolor']    = $_MG_CONF['swf_bgcolor'];
                            $playback_options['swf_version'] = $_MG_CONF['swf_version'];
                            $playback_options['flashvars']   = $_MG_CONF['swf_flashvars'];

                            $poResult = DB_query("SELECT * FROM {$_TABLES['mg_playback_options']} WHERE media_id='" . $row['media_id'] . "'");
                            while ( $poRow = DB_fetchArray($poResult) ) {
                                $playback_options[$poRow['option_name']] = $poRow['option_value'];
                            }

                            if ( $swfjsinclude > 0 ) {
                                $u_image = '';
                            } else {
                                $S = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                                $S->set_file(array('swf' => 'swfobject.thtml'));
                                $S->set_var(array(
                                    'site_url'  => $_MG_CONF['site_url'],
                                ));
                                $S->parse('output','swf');
                                $u_image = $S->finish($S->get_var('output'));
                                $swfjsinclude++;
                            }

                            $V = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                            $V->set_file (array ('video' => 'view_swf.thtml'));
                            $V->set_var(array(
                                'site_url'  => $_MG_CONF['site_url'],
                                'lang_noflash' => $LANG_MG03['no_flash'],
                                'play'      => ($autoplay ? 'true' : 'false'),
                                'menu'      => ($playback_options['menu'] ? 'true' : 'false'),
                                'loop'      => ($playback_options['loop'] ? 'true' : 'false'),
                                'scale'     => $playback_options['scale'],
                                'wmode'     => $playback_options['wmode'],
                                'flashvars' => $playback_options['flashvars'],
                                'quality'   => $playback_options['quality'],
                                'height'    => $videoheight,
                                'width'     => $videowidth,
                                'asa'       => $playback_options['allowscriptaccess'],
                                'bgcolor'   => $playback_options['bgcolor'],
                                'swf_version' => $playback_options['swf_version'],
                                'filename'  => $row['media_original_filename'],
                                'id'        => $row['media_filename'] . rand(),
                                'id2'       => $row['media_filename'] . rand(),
                                'movie'     => $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'],
                            ));
                            $V->parse('output','video');
                            $u_image .= '<div style="float:' . $align . ';padding:5px;">' . $V->finish($V->get_var('output'))  . '</div>';
                            break;
                        case 'video/x-flv' :
                            // set the default playback options...
                            $playback_options['play']    = $_MG_CONF['swf_play'];
                            $playback_options['menu']    = $_MG_CONF['swf_menu'];
                            $playback_options['quality'] = $_MG_CONF['swf_quality'];
                            $playback_options['height']  = $_MG_CONF['swf_height'];
                            $playback_options['width']   = $_MG_CONF['swf_width'];
                            $playback_options['loop']    = 0;
                            $playback_options['scale']   = $_MG_CONF['swf_scale'];
                            $playback_options['wmode']   = $_MG_CONF['swf_wmode'];
                            $playback_options['allowscriptaccess'] = $_MG_CONF['swf_allowscriptaccess'];
                            $playback_options['bgcolor']    = $_MG_CONF['swf_bgcolor'];
                            $playback_options['swf_version'] = $_MG_CONF['swf_version'];
                            $playback_options['flashvars']   = $_MG_CONF['swf_flashvars'];
                            $poResult = DB_query("SELECT * FROM {$_TABLES['mg_playback_options']} WHERE media_id='" . $row['media_id'] . "'");
                            while ( $poRow = DB_fetchArray($poResult) ) {
                                $playback_options[$poRow['option_name']] = $poRow['option_value'];
                            }
                            if ( $swfjsinclude > 0 ) {
                                $u_image = '';
                            } else {
                                $S = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                                $S->set_file(array('swf' => 'swfobject.thtml'));
                                $S->set_var(array(
                                    'site_url'  => $_MG_CONF['site_url'],
                                ));
                                $S->parse('output','swf');
                                $u_image = $S->finish($S->get_var('output'));
                                $swfjsinclude++;
                            }

                            if ( $autoplay == 1 ) {
                                $splash = '';
                            } else {
                                $splash = 'splashImageFile: \'' . $_MG_CONF['site_url'] . '/';
                                if ( $row['media_tn_attached'] == 1 ) {
                                    $splash .= '/mediaobjects/tn/' . $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg';
                                } else {
                                    $splash .= '/players/play.jpg';
                                }
                                $splash .= "',";
                            }
                            $finalFlashVar = "config={ videoFile: '" . $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'] .
                                             "?source=1', " . $splash . " autoBuffering: false, play: " . ($autoplay ? 'true' : 'false') . ", loop: false}";

                            if ( $row['remote_media'] == 1 ) {
                                $urlParts = array();
                                $urlParts = parse_url($row['remote_url']);

                                $pathParts = array();
                                $pathParts = explode('/',$urlParts['path']);

                                $ppCount = count($pathParts);
                                $pPath = '';
                                for ($i=1; $i<$ppCount-1;$i++) {
                                    $pPath .= '/' . $pathParts[$i];
                                }
                                $videoFile = $pathParts[$ppCount-1];

                                $pos = strrpos($videoFile, '.');
                                if($pos === false) {
                                    $basefilename = $videoFile;
                                } else {
                                    $basefilename = substr($videoFile,0,$pos);
                                }

                                $streamingServerURL = $urlParts['scheme'] . '://' . $urlParts['host'] . $pPath;

                                $finalFlashVar = "config={streamingServerURL: '" . $streamingServerURL . "', videoFile: '" . $basefilename . "', streamingServer: 'fms', " . $splash . " autoPlay: " . ($autoplay ? 'true' : 'false') . ", startingBufferLength: 5, bufferLength: 20, loop: false, initialScale: 'orig', hideControls: false }";
                            }

                            $V = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                            $V->set_file (array ('video' => 'view_flv_light.thtml'));
                            $V->set_var(array(
                                'site_url'  => $_MG_CONF['site_url'],
                                'lang_noflash' => $LANG_MG03['no_flash'],
                                'play'      => ($autoplay ? 'true' : 'false'),
                                'menu'      => ($playback_options['menu'] ? 'true' : 'false'),
                                'loop'      => ($playback_options['loop'] ? 'true' : 'false'),
                                'scale'     => $playback_options['scale'],
                                'wmode'     => $playback_options['wmode'],
                                'flashvars' => $finalFlashVar, // $playback_options['flashvars'],
                                'quality'   => 'high',
                                'height'    => $videoheight + 24, // allow 24px for player controls
                                'width'     => $videowidth,
                                'asa'       => 'false',
                                'bgcolor'   => '#0f0f0f', // $playback_options['bgcolor'],
                                'swf_version' => '9',
                                'filename'  => $row['media_original_filename'],
                                'id'        => 'flvvideo' . rand(),
                                'id2'       => 'flvvideo' . rand(),
                                'movie'     => $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'],
                                'splash'    => $splash,
                            ));
                            $V->parse('output','video');
                            $u_image .= '<div style="float:' . $align . ';padding:5px;">' . $V->finish($V->get_var('output'))  . '</div>';
                            break;
                    }
                    $link = $u_image;
                    if ( $destination != 'block' ) {
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    } else {
                        $autoTagCount = $mgAutoTagArray['count'];
                        $mgAutoTagArray['tags'][$autoTagCount] = $link;
                        $mgAutoTagArray['count']++;
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    }
                    return $content;
                } else {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }
                break;
            case 'audio' :
                $sql = "SELECT ma.album_id,m.mime_type,m.media_tn_attached,m.media_filename,m.media_mime_ext FROM {$_TABLES['mg_media']} AS m LEFT JOIN {$_TABLES['mg_media_albums']} AS ma ON m.media_id=ma.media_id WHERE m.media_id='" . addslashes($parm1) . "'";
                $result = DB_query($sql);
                if ( DB_numRows($result) > 0 ) {
                    $row = DB_fetchArray($result);
                    $aid = $row['album_id'];
                    if ( $MG_albums[$aid]->access == 0 ) {
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                        return $content;
                    }
                    switch( $row['mime_type'] ) {
                        case 'audio/mpeg' :
                            $playback_options['height'] = 50;;
                            $playback_options['width']  = 300;

                            $V = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                            if ( $_MG_CONF['mp3_player'] == 0 ) {
                                $tfile = 'view_mp3_wmp.thtml';
                                $autostart = $autoplay ? '1' : '0';
                            } else {
                                $tfile = 'view_mp3_qt.thtml';
                                $autostart = $autoplay ? 'true' : 'false';
                            }
                            if ( isset( $_MG_USERPREFS['mp3_player']) ) {
                                if ($_MG_USERPREFS['mp3_player'] == 0 ) {
                                    $tfile = 'view_mp3_wmp.thtml';
                                    $autostart = $autoplay ? '1' : '0';
                                }
                                if ($_MG_USERPREFS['mp3_player'] == 1 ) {
                                    $tfile = 'view_mp3_qt.thtml';
                                    $autostart = $autoplay ? 'true' : 'false';
                                }
                            }

                            if ( $row['media_tn_attached'] == 1 ) {
                                $u_tn = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg';
                                $media_size_disp  = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/tn/' . $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg');
                                $border_width = $media_size_disp[0] + 15;
                                $u_pic = '<div class=out style="width:' . $border_width . 'px"><div class="in ltin tpin"><img src="' . $u_tn . '" alt=""></div></div>';
                                if ($_MG_USERPREFS['mp3_player'] == 0 ) {
                                    $playback_options['height'] = 50;
                                }
                                if ($_MG_USERPREFS['mp3_player'] == 1 ) {
                                    $playback_options['height'] = 20;
                                }
                                $playback_options['width']  = 200;
                            } else {
                                $u_pic='';
                                if ($_MG_USERPREFS['mp3_player'] == 0 ) {
                                    $playback_options['height'] = 50;
                                }
                                if ($_MG_USERPREFS['mp3_player'] == 1 ) {
                                    $playback_options['height'] = 20;
                                }
                                $playback_options['width']  = 200;
                            }

                            $V->set_file (array ('audio' => $tfile));
                            $V->set_var(array(
                                'autostart'         => $autostart, // $autoplay ? 'true' : 'false',
                                'enablecontextmenu' => 'true',
                                'stretchtofit'      => 'false',
                                'showstatusbar'     => 'true',
                                'uimode'            => 'mini',
                                'height'            => $playback_options['height'],
                                'width'             => $playback_options['width'],
                                'bgcolor'           => '#FFFFFF',
                                'loop'              => 'true',
                                'u_pic'             => $u_pic,
                                'movie'             => $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'],
                            ));
                            $V->parse('output','audio');
                            $u_image = '<div style="float:' . $align . ';padding:5px;">' . $V->finish($V->get_var('output')) . '</div>';
                            break;
                        case 'audio/x-ms-wma' :
                        case 'audio/x-ms-wax' :
                        case 'audio/x-ms-wmv' :
                            $playback_options['height'] = 50;;
                            $playback_options['width']  = 300;

                            $V = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                            $tfile = 'view_mp3_wmp.thtml';
                            $autostart = $autoplay ? '1' : '0';
                            if ( $row['media_tn_attached'] == 1 ) {
                                $u_tn = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg';
                                $media_size_disp  = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/tn/' . $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg');
                                $border_width = $media_size_disp[0] + 15;
                                $u_pic = '<div class=out style="width:' . $border_width . 'px"><div class="in ltin tpin"><img src="' . $u_tn . '" alt=""></div></div>';
                                $playback_options['height'] = 50;
                                $playback_options['width']  = 200;
                            } else {
                                $u_pic='';
                                $playback_options['height'] = 50;
                                $playback_options['width']  = 200;
                            }

                            $V->set_file (array ('audio' => $tfile));
                            $V->set_var(array(
                                'autostart'         => $autostart, // $autoplay ? 'true' : 'false',
                                'enablecontextmenu' => 'true',
                                'stretchtofit'      => 'false',
                                'showstatusbar'     => 'true',
                                'uimode'            => 'mini',
                                'height'            => $playback_options['height'],
                                'width'             => $playback_options['width'],
                                'bgcolor'           => '#FFFFFF',
                                'loop'              => 'true',
                                'u_pic'             => $u_pic,
                                'movie'             => $_MG_CONF['site_url'] . '/mediaobjects/orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'],
                            ));
                            $V->parse('output','audio');
                            $u_image = '<div style="float:' . $align . ';padding:5px;">' . $V->finish($V->get_var('output')) . '</div>';
                            break;
                    }
                    $link = $u_image;
                    if ( $destination != 'block' ) {
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    } else {
                        $autoTagCount = $mgAutoTagArray['count'];
                        $mgAutoTagArray['tags'][$autoTagCount] = $link;
                        $mgAutoTagArray['count']++;
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    }
                    return $content;
                } else {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }
                break;
            case 'fslideshow' :
                if ( $parm1 == '' || $parm1 == 0 || !isset($MG_albums[$parm1]->id ) ) {
                    return $content;
                }
                if ( $MG_albums[$parm1]->access == 0 ) {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }
                if ( $swfjsinclude > 0 ) {
                    $swfobject = LB . '';
                } else {
                    $S = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                    $S->set_file(array('swf' => 'swfobject.thtml'));
                    $S->set_var(array(
                        'site_url'  => $_MG_CONF['site_url'],
                    ));
                    $S->parse('output','swf');
                    $swfobject = $S->finish($S->get_var('output'));
                    $swfjsinclude++;
                }
                if ( $width > 0 && $height == 0 ) {
                    $height = $width * 0.75;
                } else if ( $width == 0 && $height == 0 ) {
                    $height = $width = 200;
                } else if ( $width == 0  && $height > 0 ) {
                    $width = $height * 1.3333;
                }
                // if none of the above, assume height and width both specified.

                if ($caption == '' ) {
                    $caption = $MG_albums[$aid]->title;
                }

                $captionHTML = '<div style="width: ' . $width . 'px; text-align: center;font-style: italic;font-size: smaller;text-indent: 0;">' . $caption . '</div>';
                $ss_count++;
                $swfobject .= '<div style="float:' . $align . ';padding:5px;"><div id="mss' . $ss_count . '">' . $LANG_MG03['no_flash'] . '</div>' . LB;
                $swfobject .= '<script type="text/javascript">' . LB;
                $swfobject .= '        // <![CDATA[' . LB;
                $swfobject .= '        var so = new SWFObject("' . $_MG_CONF['site_url'] . '/players/minislideshow.swf", "minislideshow", "' . $width . '", "' . $height . '", "9.0.28.0");' . LB;
                $swfobject .= '        so.addParam("play","true");' . LB;
                $swfobject .= '        so.addParam("quality","high");' . LB;
                $swfobject .= '        so.addParam("menu","none");' . LB;
                $swfobject .= '        so.addParam("wmode","transparent");' . LB;
                $swfobject .= '        so.addVariable("xmlUrl", "' . $_MG_CONF['site_url'] . '/xml.php?aid=' . $parm1 . '%26src=' . trim($src) . '");'. LB;
                $swfobject .= '        so.addVariable("showDropShadow","true");' . LB;
                $swfobject .= '        so.addVariable("delay","' . $delay . '");' . LB;
                $swfobject .= '        so.addVariable("transInType","' . $transition . '");' . LB;
                $swfobject .= '        so.addVariable("transOutType","' . 'Fade' . '")' . LB;
                if ( $showtitle == 'bottom' || $showtitle == 'top' ) {
                    $swfobject .= '        so.addVariable("showTitle","' . $showtitle . '");' . LB;
                }
                if ( $MG_albums[$aid]->hidden || $enable_link == 0 ) {
                    $swfobject .= '        so.addVariable("noLink","' . 'true' . '");' . LB;
                }
                $swfobject .= '        so.useExpressInstall(\'' . $_MG_CONF['site_url'] . '/players/expressinstall.swf\');' . LB;
                $swfobject .= '        so.write("mss' . $ss_count . '");' . LB;
                $swfobject .= '        // ]]>' . LB;
                $swfobject .= '    </script>' . LB;

                $link = $swfobject . $captionHTML . '</div>';

                if ( $destination != 'block' ) {
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                } else {
                    $autoTagCount = $mgAutoTagArray['count'];
                    $mgAutoTagArray['tags'][$autoTagCount] = $link;
                    $mgAutoTagArray['count']++;
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                }
                return $content;
                break;
            case 'slideshow' :
                if ( $parm1 == '' || $parm1 == 0 || !isset($MG_albums[$parm1]->id ) ) {
                    return $content;
                }
                if ( $MG_albums[$parm1]->access == 0 ) {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }
                if ($caption == '' ) {
                    $caption = $MG_albums[$aid]->title;
                }
                $T->set_file (array('tag'      => 'autotag_ss.thtml'));
                $aid = $parm1;
                $pics = '';
                $counter = 0;
                $maxwidth = 0;
                $maxheight = 0;
                $ss_count++;
                $sql = "SELECT m.media_filename,m.remote_url FROM {$_TABLES['mg_media_albums']} as ma INNER JOIN " . $_TABLES['mg_media'] . " as m " .
                       " ON ma.media_id=m.media_id WHERE ma.album_id=" . addslashes($aid) . " AND m.media_type=0 AND m.include_ss=1";
                $result = DB_query($sql);
                while ($row = DB_fetchArray($result)) {
                    $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/tn/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.jpg');
                    $counter++;
                    if ( $width > 0 && $height == 0 ) {
                        if ( $media_size[0] > $media_size[1] ) {        // landscape
                            $ratio = $media_size[0] / $width;
                            $newwidth = $width;
                            $newheight = round($media_size[1] / $ratio);
                        } else {    // portrait
                            $ratio = $media_size[1] / $width;
                            $newheight = $width;
                            $newwidth = round($media_size[0] / $ratio);
                        }
                    } else if ( $width == 0 && $height == 0 ) {
                        if ( $media_size[0] > $media_size[1] ) {        // landscape
                            $ratio = $media_size[0] / 200;
                            $newwidth = 200;
                            $newheight = round($media_size[1] / $ratio);
                        } else {    // portrait
                            $ratio = $media_size[1] / 200;
                            $newheight = 200;
                            $newwidth = round($media_size[0] / $ratio);
                        }
                    } else if ( $width == 0 && $height > 0 ) {
                        if ( $height > $media_size[1] ) {
                            $newheight = $media_size[1];
                            $newwidth = $media_size[0];
                        } else {
                            $ratio = $height / $media_size[1];
                            $newheight = $height;
                            $newwidth = round($media_size[0] * $ratio);
                        }
                    } else {
                        $newwidth = $width;
                        $newheight = $height;
                    }

                    if ( $newheight > $maxheight ) {
                        $maxheight = $newheight;
                    }
                    if ( $newwidth > $maxwidth ) {
                        $maxwidth  = $newwidth;
                    }
                    if ( $MG_albums[$parm1]->hidden == 1 || $enable_link == 0 ) {
                        $pics .= '<img src="' . $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.jpg" height="' . $newheight . '" width="' . $newwidth . '" border="0" alt="">' . LB;
                    } else {
                        $ss_url = $_MG_CONF['site_url'] . '/album.php?aid=' . $aid;
                        $pics .= '<a href="' . $ss_url . '"><img src="' . $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.jpg" height="' . $newheight . '" width="' . $newwidth . '" border="0" alt=""></a>' . LB;
                    }
                }
                if ( $delay <= 0 ) {
                    $delay = 10;
                }
                if ( $counter != 0 ) {
                    $T->set_var(array(
                        'align'     => $align,
                        'pics'      => $pics,
                        'caption'   => $caption,
                        'maxheight' => $maxheight,
                        'maxwidth'  => $maxwidth,
                        'width'     => $maxwidth,
                        'framewidth' => $maxwidth + 10,
                        'ss_count'  => $ss_count,
                        'delay'     => $delay,
                        'border'    => $border ? 'border: silver solid;border-width: 1px;' : '',
                    ));
                    if ( $align == 'left' || $align == 'right' ) {
                        $T->set_var('float','float: ' . $align . ';');
                    } else {
                        $T->set_var('float','');
                    }
                    if ( $align == 'left' ) {
                        $T->set_var('margin-right','margin-right:15px;');
                    } else {
                        $T->set_var('margin-right','');
                    }
                    $T->parse('output','tag');
                    $link = $T->finish($T->get_var('output'));
                } else {
                    $link = '';
                }
                if ( $destination != 'block' ) {
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                } else {
                    $autoTagCount = $mgAutoTagArray['count'];
                    $mgAutoTagArray['tags'][$autoTagCount] = $link;
                    $mgAutoTagArray['count']++;
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                }
                return $content;
                break;
            case 'album' :
                if ( $parm1 == '' || $parm1 == 0 || !isset($MG_albums[$parm1]->id ) ) {
                    $side_count--;
                    return $content;
                }
                if ( $MG_albums[$parm1]->access == 0 ) {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    $side_count--;
                    return $content;
                }
                $ss_count++;
                if ( $border == 0 ) {
                    $T->set_file(array('tag'    => 'autotag_nb.thtml'));
                } else {
                    $T->set_file (array('tag'      => 'autotag.thtml'));
                }
                if ( $caption != '' ) {
                    $alttag = ' alt="' . $caption . '" title="' . $caption . '"';
                } else {
                    $alttag = ' alt=""';
                    if ( $_MG_CONF['autotag_caption'] ) {
                        $caption = $MG_albums[$parm1]->title;
                    }
                }
                $aid = $parm1;

                if ( $MG_albums[$parm1]->tn_attached == 1 ) {
                    $tnImage = $_MG_CONF['site_url'] . '/mediaobjects/covers/cover_' . $parm1 . '.jpg';
                    $tnFileName = $_MG_CONF['path_html'] . '/mediaobjects/covers/cover_' . $parm1 . '.jpg';
                } else {
                    $filename = $MG_albums[$aid]->findCover();
                    if ( $filename != '' ) {
                        $tnImage = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $filename[0] .'/' . $filename . '.jpg';
                        $tnFileName = $_MG_CONF['path_html'] . 'mediaobjects/tn/' . $filename[0] .'/' . $filename . '.jpg';
                    } else {
                        $tnImage = $_MG_CONF['site_url'] . '/mediaobjects/empty.gif';
                        $tnFileName = $_MG_CONF['path_html'] . 'mediaobjects/empty.gif';
                    }
                }
                $media_size = @getimagesize($tnFileName);
                if ( $media_size == false ) {
                    $tnImage = $_MG_CONF['site_url'] . '/mediaobjects/missing.png';
                    $tnFileName = $_MG_CONF['path_html'] . 'mediaobjects/missing.png';
                    $media_size = @getimagesize($tnFileName);
                }
                if ( $width > 0 && $height == 0 ) {
                    $ratio = $media_size[0] / $width;
                    $newwidth = $width;
                    $newheight = round($media_size[1] / $ratio);
                } else if ( $width == 0 && $height == 0 ) {
                    if ( $media_size[0] > $media_size[1] ) {        // landscape
                        $ratio = $media_size[0] / 200;
                        $newwidth = 200;
                        $newheight = round($media_size[1] / $ratio);
                    } else {    // portrait
                        $ratio = $media_size[1] / 200;
                        $newheight = 200;
                        $newwidth = round($media_size[0] / $ratio);
                    }
                } else if ( $width == 0 && $height > 0 ) {
                    $ratio = $height / $media_size[1];
                    $newheight = $height;
                    $newwidth = round($media_size[0] * $ratio);
                } else {
                    $newwidth = $width;
                    $newheight = $height;
                }
                $album_image = '<img src="' . $tnImage . '" height="' . $newheight . '" width="' . $newwidth . ' border="0" ' . $alttag . '>';

                $tagtext = $album_image;
                if ( $linkID == 0 ) {
                    $url = $_MG_CONF['site_url'] . '/album.php?aid=' . $parm1;
                } else {
                    $url = $_MG_CONF['site_url'] . '/media.php?s=' . $linkID;
                }
                if ( $enable_link == 0 ) {
                    $link = $tagtext;
                } else {
                    $link = '<a href="' . $url . '">' . $tagtext . '</a>';
                }
                $T->set_var(array(
                    'ss_count'   => $ss_count,
                    'align'      =>  $align,
                    'autotag'    => $link,
                    'caption'    => $caption,
                    'width'      => $newwidth,
                    'framewidth' => $newwidth + 10,
                ));
                if ( $align == 'left' || $align == 'right' ) {
                    $T->set_var('float','float:' . $align . ';');
                } else {
                    $T->set_var('float','');
                }
                if ( $align == 'left' ) {
                    $T->set_var('margin-right','margin-right:15px;');
                } else {
                    $T->set_var('margin-right','');
                }
                $T->parse('output','tag');
                $link = $T->finish($T->get_var('output'));
                if ( $destination != 'block' ) {
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                } else {
                    $autoTagCount = $mgAutoTagArray['count'];
                    $mgAutoTagArray['tags'][$autoTagCount] = $link;
                    $mgAutoTagArray['count']++;
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                }
                return $content;
                break;
            case 'media' :
            /* image, oimage and img are depreciated */
            case 'image' :
            case 'oimage' :
            case 'img' :
                if ( $parm1 == '' || $parm1 == 0 ) {
                    return $content;
                }
                $ss_count++;
                if ( $border == 0 ) {
                    $T->set_file(array('tag'    => 'autotag_nb.thtml'));
                } else {
                    $T->set_file (array('tag'      => 'autotag.thtml'));
                }
                if ( $caption != '' ) {
                    $alttag = ' alt="' . $caption . '" title="' . $caption . '"';
                } else {
                    $alttag = ' alt=""';
                }
                $sql = "SELECT ma.album_id,m.media_title,m.media_type,m.media_filename,m.media_mime_ext,m.mime_type,m.media_tn_attached,m.remote_url FROM {$_TABLES['mg_media']} AS m LEFT JOIN {$_TABLES['mg_media_albums']} AS ma ON m.media_id=ma.media_id WHERE m.media_id='" . addslashes($parm1) . "'";
                $result = DB_query($sql);
                if ( DB_numRows($result) > 0 ) {
                    $row = DB_fetchArray($result);
                    $aid = $row['album_id'];
                    if ( $MG_albums[$aid]->access == 0 ) {
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                        return $content;
                    }
                    if ( $caption == '' && $_MG_CONF['autotag_caption'] ) {
                        $caption = $row['media_title'];
                    }
                    switch( $row['media_type'] ) {
                        case 0 :    // standard image
                            if ($autotag['tag'] == 'oimage' ) {
                                if ( $_MG_CONF['discard_originals'] == 1 ) {
                                    $default_thumbnail = 'disp/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'];
                                } else {
                                    $default_thumbnail = 'orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'];
                                }
                            } else {
                                switch ( $src ) {
                                    case 'orig' :
                                        if ( $_MG_CONF['discard_originals'] == 1 ) {
                                            $default_thumbnail = 'disp/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'];
                                        } else {
                                            $default_thumbnail = 'orig/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'];
                                        }
                                        break;
                                    case 'disp' :
                                        $default_thumbnail = 'disp/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.' . $row['media_mime_ext'];
                                        break;
                                    case 'tn' :
                                        $default_thumbnail = 'tn/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.jpg';
                                        break;
                                    default :
                                        $default_thumbnail = 'tn/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.jpg';
                                        break;
                                }
                            }
                            break;
                        case 1 :    // video file
                            switch ( $row['mime_type'] ) {
                                case 'application/x-shockwave-flash' :
                                    $default_thumbnail = 'flash.gif';
                                    break;
                                case 'video/quicktime' :
                                case 'video/mpeg' :
                                    $default_thumbnail = 'quicktime.gif';
                                    break;
                                case 'video/x-ms-asf' :
                                case 'video/x-ms-wvx' :
                                case 'video/x-ms-wm' :
                                case 'video/x-ms-wmx' :
                                case 'video/x-msvideo' :
                                case 'application/x-ms-wmz' :
                                case 'application/x-ms-wmd' :
                                    $default_thumbnail = 'wmp.gif';
                                    break;
                                default :
                                    $default_thumbnail = 'video.gif';
                                    break;
                            }
                            $src = 'tn';
                            break;
                        case 2 :    // music file
                            $src = 'tn';
                            $default_thumbnail = 'audio.gif';
                            break;
                    }
                    if ( $row['media_tn_attached'] == 1 && ($src != 'orig' && $src != 'disp')) {
                        $media_thumbnail      = $_MG_CONF['site_url']  . '/mediaobjects/tn/'.  $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg';
                        $media_thumbnail_file = $_MG_CONF['path_html'] . 'mediaobjects/tn/'.  $row['media_filename'][0] . '/tn_' . $row['media_filename'] . '.jpg';
                    } else {
                        $media_thumbnail      = $_MG_CONF['site_url']  . '/mediaobjects/' . $default_thumbnail;
                        $media_thumbnail_file = $_MG_CONF['path_html'] . 'mediaobjects/' . $default_thumbnail;
                    }
                    if ( $autotag['tag'] == 'img' ) {
                        if ( $align != '' && $align != 'center' ) {
                            $album_image = '<img src="' . $media_thumbnail . '" align="' . $align . '" border="0" ' . $alttag . '>';
                        } else {
                            $album_image = '<img src="' . $media_thumbnail . '" border="0" ' . $alttag . '>';
                        }
                    } else {
                        $album_image = '<img src="' . $media_thumbnail . '" border="0" ' . $alttag . '>';
                    }
                } else {
                    return $content;
                }
                $mediaSize = @getimagesize($media_thumbnail_file);
                if ( $mediaSize == false ) {
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                    return $content;
                }

                if ( $autotag['tag'] == 'oimage' || $src == 'orig') {
                    $newwidth = $mediaSize[0];
                    $newheight = $mediaSize[1];
                } else {
                    if ( $width > 0 ) {
                        $tn_height = $width;
                    } else {
                        switch ($src) {
                            case 'orig' :
                                $tn_height = $mediaSize[0];
                                break;
                            case 'disp' :
                                $tn_height = $mediaSize[0];
                                break;
                            case 'tn' :
                                $tn_height = 200;
                                break;
                            default :
                                $tn_height = 200;
                                break;
                        }
                    }

                    if ( $mediaSize[0] > $mediaSize[1] ) {
                        $ratio = $mediaSize[0] / $tn_height;
                        $newwidth = $tn_height;
                        $newheight = round($mediaSize[1] / $ratio);
                    } else {
                        $ratio = $mediaSize[1] / $tn_height;
                        $newheight = $tn_height;
                        $newwidth = round($mediaSize[0] / $ratio);
                    }
                }
                if ( $autotag['tag'] == 'img' ) {
                    if ( $align != '' && $align != 'center' ) {
                        $album_image = '<img src="' . $media_thumbnail . '" height="' . $newheight . '" width="' . $newwidth . '" border="0" align="' . $align . '" ' . $alttag . '>';
                    } else {
                        $album_image = '<img src="' . $media_thumbnail . '" height="' . $newheight . '" width="' . $newwidth . '" border="0" ' . $alttag . '>';
                    }
                } else {
                    $album_image = '<img src="' . $media_thumbnail . '" height="' . $newheight . '" width="' . $newwidth . '" border="0" ' . $alttag . '>';
                }

                $tagtext = $album_image;
                if ( $alt == 1 && $row['remote_url'] != '' ) {
                    $url = $row['remote_url'];
                } else if ( $linkID == 0 ) {
                    $url = $_MG_CONF['site_url'] . '/media.php?s=' . $parm1;
                } else {
                    $url = $_MG_CONF['site_url'] . '/media.php?s=' . $linkID;
                }

                if ( $autotag['tag'] != 'image' && $MG_albums[$aid]->hidden != 1 && $enable_link != 0) {
                    $link = '<a href="' . $url . '">' . $tagtext . '</a>';
                } else {
                    $link = $tagtext;
                }

                if ($autotag['tag'] == 'img' ) {
                    if ( $destination != 'block' ) {
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    } else {
                        $autoTagCount = $mgAutoTagArray['count'];
                        $mgAutoTagArray['tags'][$autoTagCount] = $link;
                        $mgAutoTagArray['count']++;
                        $link = '';
                        $content = str_replace ($autotag['tagstr'], $link, $content);
                    }
                    return $content;
                }
                $T->set_var(array(
                    'ss_count'  => $ss_count,
                    'align'     =>  $align,
                    'autotag'   => $link,
                    'caption'   => $caption,
                    'width'     => $newwidth,
                    'framewidth' => $newwidth + 10,
                ));
                if ( $align == 'left' || $align == 'right' ) {
                    $T->set_var('float','float:' . $align . ';');
                } else {
                    $T->set_var('float','');
                }
                if ( $align == 'left' ) {
                    $T->set_var('margin-right','margin-right:15px;');
                } else {
                    $T->set_var('margin-right','');
                }
                $T->parse('output','tag');
                $link = $T->finish($T->get_var('output'));
                if ( $destination != 'block' ) {
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                } else {
                    $autoTagCount = $mgAutoTagArray['count'];
                    $mgAutoTagArray['tags'][$autoTagCount] = $link;
                    $mgAutoTagArray['count']++;
                    $link = '';
                    $content = str_replace ($autotag['tagstr'], $link, $content);
                }
                return $content;
                break;
        }
    }
}


/**
* returns list of moderation values
*
* The array returned contains (in order): the row 'id' label, main plugin
* table, moderation fields (comma seperated), and plugin submission table
*
* @return       array        Returns array of useful moderation values
*
*/
function plugin_moderationvalues_mediagallery() {
    return;
}

/**
* show files for moderation on submissions page
*
* Uses the Plugin class to return data required by moderation.php to list
* plugin objects that need to be moderated.
*
* @return       Plugin       return Plugin class containing submission data
*
*/
function plugin_itemlist_mediagallery() {
    return;
}

/**
* Returns the plugins submission form
*
* Returns a string contain the HTML of the submission form for the plugin.
*
* @return       string       The HTML form
*
*/
function plugin_submit_mediagallery() {
    $retval = '<h1>submit file</h1>';
    $retval .= '<p>This would be the input form for uploading files. ';
    $retval .= 'But that functionality is already implemented elsewhere.</p>';

    return($retval);
}

/**
*
* Checks that the current user has the rights to moderate the
* plugin, returns true if this is the case, false otherwise
*
* @return        boolean       Returns true if moderator
*
*/
function plugin_ismoderator_mediagallery() {
    return SEC_hasRights('mediagallery.admin');
}

/**
* Returns the number of submissions waiting moderation
*
* Calculates the number of submissions that are currently waiting
* to be moderated and returns that number.
*
* @return      int       number of submissions awaiting moderation
*/
function plugin_submissioncount_mediagallery() {
    return;
}

/**
* Performs plugin exclusive work for items approved by moderation
*
* While moderation.php handles the actual move from mediagallery submission
* to mediagallery tables, within the function we handle all other approval
* relate tasks
*
* @param      string       $id      Identifying string
* @return     string       Any wanted HTML output
*
*/
function plugin_moderationapprove_mediagallery($id)
{
    return '';
}

/**
* Performs plugin exclusive work for items deleted by moderation
*
* While moderation.php handles the actual removal from mediagallery submission
* table, within this function we handle all other deletion
* relate tasks
*
* @param      string       $id      Identifying string
* @return     string       Any wanted HTML output
*
*/
function plugin_moderationdelete_mediagallery($id) {
    return;
}

/**
* saves submission to mediagallery submission table
*
* takes data input by submission form and populates the mediagallery submission
* table.
*
* @param       array       $A       array (key => value) of form items
* @return      boolean     returns true if successful
*
*/
function plugin_savesubmission_mediagallery($A) {
    global $_TABLES, $_USER, $_CONF;
    return false;
}

function plugin_searchtypes_mediagallery()
{
    global $LANG_MG00;

    $tmp['mediagallery'] = $LANG_MG00['plugin'];
    return $tmp;
}


/**
* this searches for pages matching the user query and returns an array of
* for the header and table rows back to search.php where it will be formated and
* printed
*
* @query            string          Keywords user is looking for
* @datestart        date/time       Start date to get results for
* @dateend          date/time       End date to get results for
* @topic            string          The topic they were searching in
* @type             string          Type of items they are searching
* @author           string          Get all results by this author
*
*/
function plugin_dopluginsearch_mediagallery($query, $datestart, $dateend, $topic, $type, $author) {
    global $MG_albums, $_TABLES, $_CONF, $_MG_CONF, $LANG_MG00, $LANG_MG01, $_GET, $_POST;

    if (empty($type)) {
        $type = 'all';
    }

    $query = addslashes($query);

    $keyType = '';
    if (isset ($_POST['keyType'])) {
        $keyType = COM_applyFilter ($_POST['keyType']);
    } else if (isset ($_GET['keyType'])) {
        $keyType = COM_applyFilter ($_GET['keyType']);
    }

    // Bail if we aren't supppose to do our search
    if ($type <> 'all' AND $type <> 'mediagallery') {
        $plugin_results = new Plugin();
        $plugin_results->plugin_name = $LANG_MG00['plugin'];
        $plugin_results->searchlabel = $LANG_MG00['externpages'] . $LANG_MG00['results'];
        return $plugin_results;
    }

    // Build search SQL - Modified to exclude static PHP pages from search.

    $sqltmp = " WHERE 1=1 ";

    if ( $keyType == 'phrase' ) {
        $sqltmp .= "AND ( m.media_title LIKE '%$query%' OR m.media_desc LIKE '%$query%' OR m.media_keywords LIKE '%$query%' ) ";
    } else  if ( $keyType == 'any' ) {
        $sqltmp .= 'AND ';
        $tmp = '';
        $mywords = explode( ' ', $query );
        foreach( $mywords AS $mysearchitem ) {
            $mysearchitem = addslashes( $mysearchitem );
                $tmp .= "( m.media_title LIKE '%$query%' OR m.media_desc LIKE '%$query%' OR m.media_keywords LIKE '%$query%'  ) OR ";
        }
        $tmp = substr($tmp, 0, strlen($tmp) - 3);
        $sqltmp .= "($tmp)";
    } else if ( $keyType == 'all' ) {
        $sqltmp .= 'AND ';
        $tmp = '';
        $mywords = explode( ' ', $query );
        foreach( $mywords AS $mysearchitem ) {
            $mysearchitem = addslashes( $mysearchitem );
            $tmp .= "( m.media_title LIKE '%$query%' OR m.media_desc LIKE '%$query%' OR m.media_keywords LIKE '%$query%'  ) AND ";
        }
        $tmp = substr($tmp, 0, strlen($tmp) - 4);
        $sqltmp .= "($tmp)";
    } else {
        $sqltmp = "WHERE (m.media_title LIKE '%$query%' OR m.media_desc LIKE '%$query%' OR m.media_keywords LIKE '%$query%' )";
    }

    if ( $author != 0 ) {
        $sqltmp .= " AND media_user_id=" . $author;
    }

    // handle date ranges

    if (!empty($datestart) && !empty($dateend)) {
        $delim = substr($datestart, 4, 1);
        $sd = explode($delim,$datestart);
        $ed = explode($delim,$dateend);
        $startdate = mktime(0,0,0,$sd[1],$sd[2],$sd[0]);
        $enddate = mktime(0,0,0,$ed[1],$ed[2],$ed[0]) + 3600;
        $sqltmp .= " AND m.media_time BETWEEN '$startdate' AND '$enddate'";
    }

    $sql = "SELECT DISTINCT ma.album_id,m.media_id,m.media_title,m.media_time,m.media_views FROM " .
            $_TABLES['mg_media'] . " as m " .
            " INNER JOIN " . $_TABLES['mg_media_albums'] . " as ma " .
            " ON m.media_id=ma.media_id " . $sqltmp . " ORDER BY m.media_time DESC";

    $result = DB_query($sql);

    // OK, now create new plugin object and insert table header labels
    require_once($_CONF['path_system'] . 'classes/plugin.class.php');
    $plugin_results = new Plugin();
    $plugin_results->plugin_name = $LANG_MG00['plugin'];
    $plugin_results->searchlabel = $LANG_MG00['externpages'] . $LANG_MG00['results'];
    $plugin_results->addSearchHeading($LANG_MG00['titlemsg']);
    $plugin_results->addSearchHeading($LANG_MG00['urlmsg']);
    $plugin_results->addSearchHeading($LANG_MG00['hitsmsg']);

    $previd = -1;

    while ( $A = DB_fetchArray($result) ) {
        if ( $previd == $A['media_id'] )
            continue;
        if ( $MG_albums[$A['album_id']]->access == 0 || ($MG_albums[$A['album_id']]->hidden == 1 && $MG_albums[0]->owner_id != 1) ) {
            continue;
        }
        $previd = $A['media_id'];
        $rcnt++;
        $A['media_title'] = $A['media_title'];
        if ( $A['media_title'] == '' ) {
            $album_title = DB_getItem($_TABLES['mg_albums'],'album_title', 'album_id=' . $A['album_id']);
            $A['media_title'] = $album_title . ' - <em>' . $LANG_MG01['no_caption'] . '</em>';
        }
        $url =  $_MG_CONF['site_url'] . '/media.php?s=' . $A['media_id'];

        $media_date = COM_getUserDateTimeFormat($A['media_time']);
        $row = array('<a href="' . $url . '">' . $A['media_title'] . "</a>",
                     $media_date[0],$A['media_views']);
        $plugin_results->addSearchResult($row);
    }
    $plugin_results->num_searchresults = $rcnt;
    $plugin_results->num_itemssearched = DB_count($_TABLES['mg_media']);

    return $plugin_results;
}

/**
* Returns the user option for this plugin
*
* Adds the plugin to the user menu
*
* Universal Plugin:  modify/uncomment use it
*
* @return   array   Array containing (plugin name, plugin user url, 0)
*
*/
function plugin_getuseroption_mediagallery() {
    global $_CONF, $_MG_CONF, $_USER, $LANG_MG01;

    if ( $_MG_CONF['up_display_rows_enabled'] == 0 &&
         $_MG_CONF['up_display_columns_enabled'] == 0 &&
         $_MG_CONF['up_mp3_player_enabled'] == 0 &&
         $_MG_CONF['up_av_playback_enabled'] == 0 &&
         $_MG_CONF['up_thumbnail_size_enabled'] == 0) {
             return '';
    }

    if ( isset($_USER['uid']) && $_USER['uid'] > 1) {
        return array($LANG_MG01['user_prefs'], $_MG_CONF['site_url'] . '/userprefs.php', 0);
    }
}

function phpblock_mg_randommedia(){
    global $_CONF, $_MG_CONF, $_TABLES, $_USER, $LANG_MG03, $_DB_dbms, $mg_installed_version;

    $retval = '';
    $gotit = 0;

    if ( $mg_installed_version != $_MG_CONF['version'] ) {
        return $retval;
    }

    if ( $_DB_dbms == 'mssql' ) {
        $randomSelect = "NewID() ";
    } else {
        $randomSelect = "RAND(NOW()) ";
    }

    $sql = "SELECT ma.album_id,m.media_id,m.media_filename,m.media_title FROM {$_TABLES['mg_albums']} as a LEFT JOIN {$_TABLES['mg_media_albums']} as ma
            on a.album_id=ma.album_id LEFT JOIN {$_TABLES['mg_media']} as m on ma.media_id=m.media_id WHERE
            m.media_type=0 AND a.enable_random=1 AND a.hidden=0 " . COM_getPermSQL('and') . " ORDER BY " . $randomSelect . "LIMIT 1";

    $result = DB_query( $sql,1 );
    $nRows  = DB_numRows( $result );
    if ( $nRows > 0 ) {
        $row    = DB_fetchArray( $result );
        $gotit = true;
    } else {
        $gotit = false;
    }

    if ( $gotit ) {
        $T = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
        $T->set_file (array ('rblock' => 'random_block.thtml'));
        $T->set_var('site_url', $_CONF['site_url']);
        $T->set_var('site_admin_url', $_CONF['site_admin_url']);
        $url_media      = $_MG_CONF['site_url'] . '/media.php?s=' . $row['media_id'];

        $url_album      = $_MG_CONF['site_url'] . '/album.php?aid=' . $row['album_id'];
        $media_thumbnail= $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $row['media_filename'][0] .'/' . $row['media_filename'] . '.jpg';

        /* --- You no longer need to modify the code to alter the random image block - see MG configuration -- */

        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/disp/' . $row['media_filename'][0] .'/' . $row['media_filename'] . '.jpg');
        if ($msize == false ) {
            return '';
        }
        $imgwidth = $msize[0];
        $imgheight = $msize[1];
        if ( !isset($_MG_CONF['random_width']) || $_MG_CONF['random_width'] == 0 ) {
            $_MG_CONF['random_width'] = 120;
        }
        if ( $imgwidth > $imgheight ) {
            $ratio = $imgwidth / $_MG_CONF['random_width'];
            $width = $_MG_CONF['random_width'];
            $height = round($imgheight / $ratio);
        } else {
            $ratio = $imgheight / $_MG_CONF['random_width'];
            $height = $_MG_CONF['random_width'];
            $width = round($imgwidth / $ratio);
        }

        $T->set_var(array(
            'url_media'         =>  $url_media,
            'url_album'         =>  $url_album,
            'media_thumbnail'   =>  $media_thumbnail,
            'media_height'      =>  $height,
            'media_width'       =>  $width,
            'border_width'      =>  $width + 14,
            'media_title'       =>  strip_tags($row['media_title']),
            'lang_browse_album' =>  $LANG_MG03['browse_album']
        ));

        $T->parse('output', 'rblock');
        $retval .= $T->finish($T->get_var('output'));
    }

    return $retval;
}

function phpblock_mg_maenroll(){
    global $_CONF, $_MG_CONF, $_MG_USERPREFS, $_TABLES, $_USER, $LANG_MG03;

    if ( $_MG_CONF['member_albums'] != 1 || $_MG_USERPREFS['member_gallery'] == 1 || $_USER['uid'] < 3) {
        return;
    }
    if ( SEC_inGroup("Remote Users") && $_MG_CONF['allow_remote'] != 1 ) {
        return;
    }

    $url = sprintf($LANG_MG03['member_album_signup'], $_MG_CONF['site_url'] . '/enroll.php');
    return $url;
}


function plugin_centerblock_mediagallery($where=1,$page=1,$topic =''){
    global $_CONF, $_MG_CONF, $MG_albums, $_TABLES, $_USER, $LANG_MG00, $LANG_MG01, $LANG_MG03,$mg_installed_version;

    $pi_name = 'mediagallery';     // Plugin name
    $retval = '';

    if ( $mg_installed_version != $_MG_CONF['version'] ) {
        return $retval;
    }

    if ( $_USER['uid'] < 2 && $_MG_CONF['loginrequired'] == 1) {
        return '';
    }

    if ( $topic == '' ) {
        $sTopic = "none";
    } else {
        $sTopic = $topic;
    }

    if ($_MG_CONF['feature_member_album'] == 1 && $_MG_CONF['member_albums'] == 1 && $_USER['uid'] > 1 && $where == 1) {
        $cbpos = 1; //top of page
        $cbpage = 'none';

        if ($cbpage == 'none' && ($page > 1 OR $topic != "")){
            $cbenable = 0;
        } elseif ($cbpage == 'all' && $page > 1 ){
            $cbenable = 0;
        } elseif ($cbpage != 'none' && $cbpage != 'all' && $cbpage != $topic) { // $cbpage != $topic) {
            $cbenable = 0;
        } else
            $cbenable = 1;

        if ( $cbenable == 1 ) {
            $sql = "SELECT album_id FROM {$_TABLES['mg_albums']} WHERE owner_id=" . $_USER['uid'] . " AND album_parent=" . $_MG_CONF['member_album_root'] . " LIMIT 1";
            $result = DB_query($sql);
            $numRows = DB_numRows($result);
            if ( $numRows > 0 ) {
                $A = DB_fetchArray($result);
                $album_id = $A['album_id'];

                $T = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
                $T->set_file ('page', 'cb_featured_album.thtml');

                require_once($_MG_CONF['path_html'] . 'classAlbum.php');

                if ($MG_albums[$album_id]->last_update > 0 ) {
                    $album_last_update = MG_getUserDateTimeFormat($MG_albums[$album_id]->last_update);
                } else {
                    $album_last_update = '';
                }
                $cover = $MG_albums[$album_id]->findCover();
                if ( $cover != '' ) {
                    $album_last_image   = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $cover[0] .'/' . $cover . '.jpg';
                    $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/tn/' . $cover[0] .'/' . $cover . '.jpg');
                } else {
                    $album_last_image = $_MG_CONF['site_url'] . '/mediaobjects/empty.gif';
                    $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/empty.gif');
                }
                $album_media_count = $MG_albums[$album_id]->getMediaCount();
                $updated_prompt = ($_MG_CONF['dfid']=='99' ? '' : $LANG_MG03['updated_prompt']);
                $album_title = $MG_albums[$album_id]->title;
                $album_desc  = $MG_albums[$album_id]->description;

                if ( $MG_albums[$album_id]->tn_attached == 1 ) {
                    $album_last_image = $_MG_CONF['site_url'] . '/mediaobjects/covers/cover_' . $MG_albums[$album_id]->id . '.jpg';
                    $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/covers/cover_' . $MG_albums[$album_id]->id . '.jpg');
                }
                if ( $media_size == false ) {
                    $album_last_image = $_MG_CONF['site_url'] . '/mediaobjects/missing.png';
                    $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/missing.png');
                }

                if ( !empty($MG_albums[$album_id]->children ) ) {
                    $saRows = 0;
                    $SAchildren = $MG_albums[$album_id]->getChildren();
                    foreach($SAchildren as $SAchild) {
                        if ( $MG_albums[$SAchild]->access > 0 ) {
                            $mediaCount = $MG_albums[$SAchild]->getMediaCount();
                            $subAlbumDisplay .= '<li><a href="' . $_MG_CONF['site_url'] . '/album.php?aid=' . $MG_albums[$SAchild]->id . '&amp;page=1' . '">' . $MG_albums[$SAchild]->title . ' (' . $mediaCount . ')</a>';
                            $saRows++;
                        }
                    }
                    $T->set_var(array(
                        'lang_subalbums'    =>  $LANG_MG01['subalbums'],
                        'subalbumcount'     =>  '(' . $saRows . ')',
                        'subalbumlist'      =>  $subAlbumDisplay
                    ));
                } else {
                    $T->set_var(array(
                        'lang_subalbums'    =>  '',
                        'subalbumcount'     =>  '',
                        'subalbumlist'      =>  ''
                    ));
                }

                switch ($_MG_CONF['gallery_tn_size'] ) {
                    case '0' :      //small
                        $tn_height = 100;
                        break;
                    case '1' :      //medium
                        $tn_height = 150;
                        break;
                    case '2' :
                        $tn_height = 200;
                        break;
                }
                if ( $media_size[0] > $media_size[1] ) {
                    $ratio = $media_size[0] / $tn_height;
                    $newwidth = $tn_height;
                    $newheight = round($media_size[1] / $ratio);
                } else {
                    $ratio = $media_size[1] / $tn_height;
                    $newheight = $tn_height;
                    $newwidth = round($media_size[0] / $ratio);
                }

                $T->set_var(array(
                    'site_url'          => $_CONF['site_url'],
                    'album_id'          => $album_id,
                    'album_title'       => $album_title,
                    'album_desc'        => $album_desc,
                    'album_media_count' => $album_media_count,
                    'subalbum_media_count' => $album_media_count,
                    'album_last_update' => $album_last_update[0],
                    'updated_prompt'    => ($MG_albums[$album_id]->last_update > 0 ? $updated_prompt : ''),
                    'album_last_image'  => $album_last_image,
                    'img_height'        => $newheight,
                    'img_width'         => $newwidth,
                    'media_size'        => 'width="' . $newwidth . '" height="' . $newheight . '"',
                    'border_width'      => $newwidth + 20,
                    'border_height'     => $newheight + 20,
                    'column_width'      => $newwidth + 30,
                    'u_viewalbum'       => $_MG_CONF['site_url'] . '/album.php?aid=' . $album_id . '&amp;page=1',
                    'lang_album'        => $LANG_MG00['album'],
                    'featured_album'    => 'Your Member Album', // $LANG_MG03['featured_album']
                ));

                $T->parse('output','page');
                $retval = $T->finish($T->get_var('output'));
                return $retval;
            }
        }
    }

    $result = DB_query("SELECT album_id, cbpage, cbposition FROM {$_TABLES['mg_albums']} WHERE featured='1' AND (cbpage='" . $sTopic . "' OR cbpage='all') " . COM_getPermSQL('and') . " LIMIT 1");

    if (DB_numRows($result) == 1) {
        list($album_id,$cbpage,$cbpos) = DB_fetchArray($result);

        // If enabled only for homepage and this is not page 1 or a topic page, then set disable flag
        if ($cbpage == 'none' && ($page > 1 OR $topic != "")){
            $cbenable = 0;
        } elseif ($cbpage == 'all' && $page > 1 ){
            $cbenable = 0;
        } elseif ($cbpage != 'none' && $cbpage != 'all' && $cbpage != $topic) { // $cbpage != $topic) {
            $cbenable = 0;
        } else
            $cbenable = 1;

        // Check if there are no featured articles in this topic and if so then place it at the top of the page
        if ($topic != "") {
            $wheresql = "WHERE tid='$topic' AND featured > 0";
        } else {
            $wheresql = "WHERE featured = 1";
        }
        $query = DB_query("SELECT count(*) as count FROM {$_TABLES['stories']} $wheresql");
        $result = DB_fetchArray($query);
        if ($result['count'] == 0 && $cbpos == 2) {
            $cbpos = 1;//top of page
        }

        if ($cbenable AND $cbpos == $where) {
            $T = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
            $T->set_file ('page', 'cb_featured_album.thtml');

            require_once($_MG_CONF['path_html'] . 'classAlbum.php');

            if ($MG_albums[$album_id]->last_update > 0 ) {
                $album_last_update = MG_getUserDateTimeFormat($MG_albums[$album_id]->last_update);
            } else {
                $album_last_update = '';
            }
            $cover = $MG_albums[$album_id]->findCover();
            if ( $cover != '' ) {
                $album_last_image   = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $cover[0] .'/' . $cover . '.jpg';
                $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/tn/' . $cover[0] .'/' . $cover . '.jpg');
            } else {
                $album_last_image = $_MG_CONF['site_url'] . '/mediaobjects/empty.gif';
                $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/empty.gif');
            }
            $album_media_count = $MG_albums[$album_id]->getMediaCount();
            $updated_prompt = ($_MG_CONF['dfid']=='99' ? '' : $LANG_MG03['updated_prompt']);
            $album_title = $MG_albums[$album_id]->title;
            $album_desc  = $MG_albums[$album_id]->description;

            if ( $MG_albums[$album_id]->tn_attached == 1 ) {
                $album_last_image = $_MG_CONF['site_url'] . '/mediaobjects/covers/cover_' . $MG_albums[$album_id]->id . '.jpg';
                $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/covers/cover_' . $MG_albums[$album_id]->id . '.jpg');
            }
            if ( $media_size == false ) {
                $album_last_image = $_MG_CONF['site_url'] . '/mediaobjects/missing.png';
                $media_size = @getimagesize($_MG_CONF['path_html'] . 'mediaobjects/missing.png');
            }

            if ( !empty($MG_albums[$album_id]->children ) ) {
                $saRows = 0;
                $SAchildren = $MG_albums[$album_id]->getChildren();
                foreach($SAchildren as $SAchild) {
                    if ( $MG_albums[$SAchild]->access > 0 ) {
                        $mediaCount = $MG_albums[$SAchild]->getMediaCount();
                        $subAlbumDisplay .= '<li><a href="' . $_MG_CONF['site_url'] . '/album.php?aid=' . $MG_albums[$SAchild]->id . '&amp;page=1' . '">' . $MG_albums[$SAchild]->title . ' (' . $mediaCount . ')</a>';
                        $saRows++;
                    }
                }
                $T->set_var(array(
                    'lang_subalbums'    =>  $LANG_MG01['subalbums'],
                    'subalbumcount'     =>  '(' . $saRows . ')',
                    'subalbumlist'      =>  $subAlbumDisplay
                ));
            } else {
                $T->set_var(array(
                    'lang_subalbums'    =>  '',
                    'subalbumcount'     =>  '',
                    'subalbumlist'      =>  ''
                ));
            }

            switch ($_MG_CONF['gallery_tn_size'] ) {
                case '0' :      //small
                    $tn_height = 100;
                    break;
                case '1' :      //medium
                    $tn_height = 150;
                    break;
                case '2' :
                    $tn_height = 200;
                    break;
            }
            if ( $media_size[0] > $media_size[1] ) {
                $ratio = $media_size[0] / $tn_height;
                $newwidth = $tn_height;
                $newheight = round($media_size[1] / $ratio);
            } else {
                $ratio = $media_size[1] / $tn_height;
                $newheight = $tn_height;
                $newwidth = round($media_size[0] / $ratio);
            }

            $T->set_var(array(
                'album_id'          => $album_id,
                'album_title'       => $album_title,
                'album_desc'        => $album_desc,
                'album_media_count' => $album_media_count,
                'subalbum_media_count' => $album_media_count,
                'album_last_update' => $album_last_update[0],
                'updated_prompt'    => ($MG_albums[$album_id]->last_update > 0 ? $updated_prompt : ''),
                'album_last_image'  => $album_last_image,
                'img_height'        => $newheight,
                'img_width'         => $newwidth,
                'media_size'        => 'width="' . $newwidth . '" height="' . $newheight . '"',
                'border_width'      => $newwidth + 20,
                'border_height'     => $newheight + 20,
                'column_width'      => $newwidth + 30,
                'u_viewalbum'       => $_MG_CONF['site_url'] . '/album.php?aid=' . $album_id . '&amp;page=1',
                'lang_album'        => $LANG_MG00['album'],
                'featured_album'    => $LANG_MG03['featured_album']
            ));

            $T->parse('output','page');
            $retval = $T->finish($T->get_var('output'));
            return $retval;
        }
    }
}

function plugin_chkVersion_mediagallery() {
    global $_MG_CONF;

    return $_MG_CONF['version'];
}

function plugin_upgrade_mediagallery()
{
    global $_TABLES, $_CONF, $_MG_CONF, $_DB_dbms;

    include ($_CONF['path'] . '/plugins/mediagallery/upgrade.inc');

    $currentVersion = DB_getItem($_TABLES['plugins'],'pi_version',"pi_name='mediagallery'");

    switch( $currentVersion ) {
        case "0.80" :
            if ( MG_upgrade_090() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='0.90' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "0.90" :
        case "0.91" :
        case "0.92" :
        case "0.92a" :
        case "0.92b" :
            if ( MG_upgrade_095() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='0.95' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "0.95" :
        case "0.95b1" :
        case "0.95b2" :
        case "0.95beta1" :
        case "0.95beta2" :
        case "0.95rc1" :
        case "0.95rc2" :
        case "0.95rc3" :
        case "0.95rc4" :
            if ( MG_upgrade_096() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='0.97' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "0.96b1" :
        case "0.96b2" :
            if ( MG_upgrade_096b() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='0.97' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "0.96b3" :
        case "0.97" :
            if ( MG_upgrade_098() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='0.98' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "0.98"   :
        case "0.98a"  :
        case "0.98b"  :
        case "0.98c"  :
            if ( MG_upgrade_120() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.2.1' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.1.0" :
        case "1.02cvs" :
            DB_query("ALTER TABLE {$_TABLES['mg_albums']} ADD `full_display` TINYINT( 4 ) DEFAULT '0' NOT NULL AFTER `albums_first`",1);
            DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.2.1' WHERE pi_name='mediagallery' LIMIT 1");
        case "1.2.0rc1" :
            DB_query("ALTER TABLE {$_TABLES['mg_playback_options']} ADD UNIQUE (`media_id` ,`option_name`);",1);
            DB_query("ALTER TABLE {$_TABLES['mg_albums']} ADD INDEX ( `last_update` )",1);
            DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.2.1' WHERE pi_name='mediagallery' LIMIT 1",1);
        case "1.2.0rc2" :
        case "1.2.0rc3" :
        case "1.2.1" :
        case "1.2.2" :
        case "1.2.3" :
        case "1.2.4" :
        case "1.2.5" :
        case "1.2.6" :
            if ( MG_upgrade_131() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.1' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.1" :
        case "1.3.2" :
            if ( MG_upgrade_133() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.3' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.3" :
            if ( MG_upgrade_134() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.4' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.4" :
            if ( MG_upgrade_135() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.5' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.5" :
            if ( MG_upgrade_136() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.6' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.6" :
            if ( MG_upgrade_137() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.7' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.7" :
            if ( MG_upgrade_138() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.8' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.8" :
            if ( MG_upgrade_139() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.9' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.9" :
            if ( MG_upgrade_1310() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.10' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.10" :
        case "1.3.11" :
            if ( MG_upgrade_1312() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.3.12' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.3.12" :
        case "1.3.C" :
        case "1.4.0RC1" :
        case "1.4.0RC2" :
        case "1.4.0RC3" :
        case "1.4.1"  :
        case "1.4.2"  :
        case "1.4.3"  :
        case "1.4.3a" :
            if ( MG_upgrade_144() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.4.4' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.4.4" :
            if ( MG_upgrade_145() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.4.5' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.4.5" :
            if ( MG_upgrade_146() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.4.6' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.4.6" :
        case "1.4.7" :
            if ( MG_upgrade_148() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.4.8' WHERE pi_name='mediagallery' LIMIT 1");
            }
        case "1.4.8" :
        case "1.4.8a" :
        case "1.4.8b" :
            if ( MG_upgrade_150() == 0 ) {
                DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='1.5.0' WHERE pi_name='mediagallery' LIMIT 1");
            }
        default :
            if ( $_DB_dbms != 'mssql' ) {
                // we missed media_keywords field somewhere along the way...
                $result = DB_query("SHOW COLUMNS FROM {$_TABLES['mg_mediaqueue']}");
                $numColumns = DB_numRows($result);
                $x=0;
                while ( $x < $numColumns ) {
                    $colname = DB_fetchArray($result);
                    $col[$colname[0]] = $colname[0];
                    $x++;
                }
                if ( $col['media_category'] != 'media_category' ) {
                    DB_query("ALTER TABLE {$_TABLES['mg_mediaqueue']} ADD `media_category` int(11) NOT NULL default '0' AFTER `media_upload_time`");
                }
                if ( $col['media_keywords'] != 'media_keywords' ) {
                    DB_query("ALTER TABLE {$_TABLES['mg_mediaqueue']} ADD `media_keywords` varchar(255) NOT NULL default '' AFTER `media_desc`");
                }
            }

            // now we do a little housekeeping...

            $album = array();
            $sql = "SELECT album_id FROM {$_TABLES['mg_albums']}";
            $result = DB_query($sql);
            $albumCount  = DB_numRows($result);
            for ($i=0; $i < $albumCount; $i++ ) {
                $album[] = DB_fetchArray($result);
            }
            for ($i=0; $i<$albumCount; $i++) {
                // set media count...
                $mediaCount  = DB_count($_TABLES['mg_media_albums'],'album_id',$album[$i]['album_id']);
                $sql = "UPDATE {$_TABLES['mg_albums']} set media_count=" . $mediaCount  . " WHERE album_id=" . $album[$i]['album_id'];
                DB_query($sql);
            }

            // rebuild the disk usage statistics

            $res1 = DB_query("SELECT album_id FROM {$_TABLES['mg_albums']}");
            while ( $row = DB_fetchArray($res1)) {
                $quota = 0;
                $sql = "SELECT m.media_filename, m.media_mime_ext FROM {$_TABLES['mg_media_albums']} as ma INNER JOIN " . $_TABLES['mg_media'] . " as m " .
                        " ON ma.media_id=m.media_id WHERE ma.album_id=" . $row['album_id'];

                $result = DB_query( $sql );
                while (list($filename, $mimeExt) = DB_fetchArray($result)) {
                    if ( $_MG_CONF['discard_original'] == 1 ) {
                        $quota += @filesize($_MG_CONF['path_html'] . '/mediaobjects/orig/' . $filename[0] . '/' . $filename . '.' . $mimeExt);
                        $quota += @filesize($_MG_CONF['path_html'] . '/mediaobjects/disp/' . $filename[0] . '/' . $filename . '.jpg');
                    } else {
                        $quota += @filesize($_MG_CONF['path_html'] . '/mediaobjects/orig/' . $filename[0] . '/' . $filename . '.' . $mimeExt);
                    }
                }
                DB_query("UPDATE {$_TABLES['mg_albums']} SET album_disk_usage=" . $quota . " WHERE album_id=" . $row['album_id']);
            }

            DB_query("UPDATE {$_TABLES['plugins']} SET pi_homepage='http://www.gllabs.org' WHERE pi_name='mediagallery'",1);
            DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='" . $_MG_CONF['version'] . "' WHERE pi_name='mediagallery' LIMIT 1");
            break;
    }
    if ( DB_getItem($_TABLES['plugins'],'pi_version',"pi_name='mediagallery'") == $_MG_CONF['version']) {
        return 1;
    } else {
        return 3;
    }
}

/**
* Removes the data structures for this plugin from the Geeklog database.
* This routine will get called from the Plugin install program if user select De-Install or if Delete is used in the Plugin Editor.
* The Plugin Installer will also call this routine upon and install error to remove anything it has created.
* The Plugin installer will pass the optional parameter which will then double check that plugin has first been disabled.
*
* For this plugin, this routine will also remove the Block definition.
*
* Returns True if all Plugin related data is removed without error
*
* @param    string   $installCheck     Defult is blank but if set, check if plugin is disabled first
*
* @return   boolean True if successful false otherwise
*
*/
function plugin_uninstall_mediagallery($installCheck='') {
    global $_DB_table_prefix, $_TABLES, $LANG_MG00;

    $pi_name    = 'mediagallery';

    $FEATURES   = array ( 'mediagallery.admin','mediagallery.config');

    $TABLES     = array ( 'mg_albums','mg_media','mg_media_albums','mg_usage_tracking','mg_config', 'mg_media_queue', 'mg_media_album_queue','mg_playback_options','mg_userprefs','mg_exif_tags', 'mg_watermarks', 'mg_category', 'mg_batch_sessions', 'mg_batch_session_items', 'mg_batch_session_items2','mg_batch_session_log', 'mg_sort', 'mg_postcard');

    // Check and see if plugin is still enabled - if so display warning and exit
    if ($installCheck != '' && DB_getItem($_TABLES['plugins'],'pi_enabled', 'pi_name = "' .$pi_name. '"')) {
        COM_errorLog("Plugin is installed and enabled. Disable first if you want to de-install it",1);
        $display .= COM_startBlock($LANG_MG00['warning']);
        $display .= $LANG_MG00['enabled'];
        $display .= COM_endBlock();
        echo $display;
        return false;
    }

    // Ok to proceed and delete plugin

    // Unregister the plugin with Geeklog
    COM_errorLog('Attempting to unregister the Media Gallery Plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'mediagallery'",1);

    // Drop mediagallery tables
    foreach($TABLES as $table) {
        COM_errorLog("Removing Table $table",1);
        DB_query("DROP TABLE " . $_DB_table_prefix . $table,1);
    }

    // Remove Security for this plugin
    $grp_id = DB_getItem($_TABLES['vars'], 'value', "name = '{$pi_name}_gid'");
    $cgrp_id = DB_getItem($_TABLES['vars'],'value', "name = '{$pi_name}_cid'");

    COM_errorLog("Removing $pi_name Admin Group", 1);
    DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id",1);
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = '{$pi_name}_gid'");
    DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $cgrp_id",1);
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = '{$pi_name}_cid'");

    COM_errorLog("Removing root users from admin of $pi_name");
    DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id",1);
    DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $cgrp_id",1);

    COM_errorLog("Removing comments for " . $pi_name);
    DB_query("DELETE FROM {$_TABLES['comments']} WHERE type='mediagallery'",1);

    // Remove all the associated features -- access rights
    foreach ($FEATURES as $feature) {
        COM_errorLog("Removing $feature feature and rights to it",1);
        $feat_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = '$feature'");
        DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $feat_id",1);
        DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $feat_id",1);
    }

    DB_query("DELETE FROM {$_TABLES['blocks']} WHERE name='mgrandom'",1);
    DB_query("DELETE FROM {$_TABLES['blocks']} WHERE name='mgenroll'",1);

    COM_errorLog('...success',1);
    return true;
}
// not available in Geeklog v1.3 so define if not here already
if (!function_exists('COM_numberFormat') ) {
    /** Converts a number for output into a formatted number with thousands-
    *         separator, comma-separator and fixed decimals if necessary
    *
    *        @param        float        $number        Number that will be formatted
    *        @return        string                        formatted number
    */
    function COM_numberFormat( $number )
    {
        global $_CONF;

        if( $number - abs( $number ) > 0 ) // number has decimals
        {
            $dc = $_CONF['decimal_count'];
        }
        else
        {
            $dc = 0;
        }
        $ts = $_CONF['thousand_separator'];
        $ds = $_CONF['decimal_separator'];

        return number_format( $number, $dc, $ds, $ts );
    }
}

if ( !function_exists('COM_truncate') ) {
    function COM_truncate( $text, $maxlen, $filler = '' ) {
        $newlen = $maxlen - strlen( $filler );
        $len = strlen( $text );
        if( $len > $maxlen ) {
            $text = substr( $text, 0, $newlen ) . $filler;
        }
        return $text;
    }
}

function plugin_user_create_mediagallery( $uid, $force = 0 ) {
    global $_TABLES, $_MG_CONF, $LANG_MG01;

    $sql = "INSERT INTO {$_TABLES['mg_userprefs']} (uid, active, display_rows, display_columns, mp3_player, playback_mode, tn_size, quota, member_gallery) VALUES (" . $uid . ",1,0,0,-1,-1,-1," . $_MG_CONF['member_quota'] . ",0)";
    DB_query($sql,1);

    $retval = -1;
    if ( $force == 1 || ($_MG_CONF['member_albums'] == 1 && $_MG_CONF['member_auto_create'] == 1) ) {
        $username               = DB_getItem($_TABLES['users'],'username','uid=' . $uid);
        $fullname               = DB_getItem($_TABLES['users'],'fullname','uid=' . $uid);
        $grp_id                 = DB_getItem($_TABLES['vars'], 'value','name="mediagallery_gid"');

        $album = new mgAlbum();

        $title = $username . $LANG_MG01['member_album_postfix'];
        if ( !empty($fullname) && $_MG_CONF['member_use_fullname'] == 1 ) {
            $title = $fullname . $LANG_MG01['member_album_postfix'];
        }
        $album->title           = htmlspecialchars(strip_tags(COM_checkWords($title)));
        $album->parent          = $_MG_CONF['member_album_root'];
        $album->group_id        = $grp_id;
        $album->mod_group_id    = $grp_id; // $_MG_CONF['member_mod_group_id'];
        $album->owner_id        = $uid;
        $album->moderate        = $_MG_CONF['member_moderate'];
        $album->email_mod       = $_MG_CONF['member_email_mod'];
        $album->perm_owner      = $_MG_CONF['member_perm_owner'];
        $album->perm_group      = $_MG_CONF['member_perm_group'];
        $album->perm_members    = $_MG_CONF['member_perm_members'];
        $album->perm_anon       = $_MG_CONF['member_perm_anon'];
        $album->id              = $album->createAlbumID();
        $retval = $album->id;
        $album->saveAlbum();
        $result = DB_query("UPDATE {$_TABLES['mg_userprefs']} SET member_gallery=1 WHERE uid=" . $uid,1);
    }
    return $retval;
}

function plugin_user_delete_mediagallery( $uid ) {
    global $_USER, $_CONF, $_TABLES, $_MG_CONF, $LANG_MG00, $LANG_MG01;

    // remove any user preferences in the database

    $sql = "DELETE FROM {$_TABLES['mg_userprefs']} WHERE uid=" . $uid;
    DB_query($sql,1);

    if ( $_MG_CONF['member_albums'] ) {
        if ( $_MG_CONF['member_album_archive'] == 0 ) {
            $sql = "SELECT album_id FROM {$_TABLES['mg_albums']} WHERE owner_id=" . $uid;
            $result = DB_query($sql);
            while ( $A = DB_fetchArray($result) ) {
                MG_deleteMemberAlbums($A['album_id']);
            }
        } else {
            // update parent album to be archive album
            $sql = "UPDATE {$_TABLES['mg_albums']} SET album_parent=" . $_MG_CONF['member_album_archive'] . " WHERE owner_id=" . $uid . " AND album_parent=" . $_MG_CONF['member_album_root'];
            DB_query($sql);
        }
    }
}

function MG_deleteMemberAlbums( $album_id ){
    global $_CONF, $_MG_CONF, $_TABLES, $_USER;

    $sql = "SELECT ma.media_id, m.media_filename, m.media_mime_ext
            FROM " . $_TABLES['mg_media_albums'] .
            " as ma LEFT JOIN " . $_TABLES['mg_media'] .
            " as m ON ma.media_id=m.media_id
            WHERE ma.album_id = " . $album_id;

    $result = DB_query( $sql );
    $nRows = DB_numRows( $result );
    $mediarow = array();
    for ( $i=0; $i < $nRows; $i++) {
      $row = DB_fetchArray( $result );
      $mediarow[] = $row;
    }
    if ( count( $mediarow ) != 0 ) {
        for ( $i = 0; $i < count( $mediarow ); $i++ ) {
            $sql = "SELECT COUNT(media_id) AS count FROM " . $_TABLES['mg_media_albums'] . "  WHERE media_id = '" . $mediarow[$i]['media_id'] . "'";
            $result = DB_query( $sql );
            $row = DB_fetchArray( $result );
            if ( $row['count'] <= 1 ) {
                @unlink($_MG_CONF['path_html'] . 'mediaobjects/tn/'   . $mediarow[$i]['media_filename'][0] .'/' . $mediarow[$i]['media_filename'] . '.jpg');
                @unlink($_MG_CONF['path_html'] . 'mediaobjects/disp/' . $mediarow[$i]['media_filename'][0] .'/' . $mediarow[$i]['media_filename'] . '.jpg');
                @unlink($_MG_CONF['path_html'] . 'mediaobjects/orig/' . $mediarow[$i]['media_filename'][0] .'/' . $mediarow[$i]['media_filename'] . '.' . $mediarow[$i]['media_mime_ext']);
                $sql = "DELETE FROM " . $_TABLES['mg_media'] . "  WHERE media_id = '" . $mediarow[$i]['media_id'] . "'";
                DB_query( $sql );
                DB_delete($_TABLES['comments'], 'sid', $mediarow[$i]['media_id']);
                DB_delete($_TABLES['mg_playback_options'],'media_id', $mediarow[$i]['media_id']);
            }
        }
    }
    $sql = "DELETE FROM " . $_TABLES['mg_media_albums'] . " WHERE album_id = " . $album_id;
    DB_query( $sql );
    $sql = "DELETE FROM " . $_TABLES['mg_albums'] . " WHERE album_id = " . $album_id;
    DB_query( $sql );
}

// display user info in profile

function plugin_profileblocksdisplay_mediagallery( $uid ) {
    global $MG_albums,$_TABLES, $_MG_CONF, $_CONF, $LANG_MG10, $_USER;

    $retval = '';

    if ( $_MG_CONF['profile_hook'] == 0 ) {
        return '';
    }

    if ( $_USER['uid'] < 2 && $_MG_CONF['loginrequired'] == 1) {
        return '';
    }

    if ( $uid == '' ) {
        return '';
    }

    $template = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
    $template->set_file(array(
        'mblock' => 'mediablock.thtml',
        'mrow'   => 'mediarow.thtml',
//        'arow'   => 'albumrow.thtml'
    ));

    $username = DB_getItem($_TABLES['users'], 'username', 'uid=' . $uid);
    if ( $username == '' ) {
        return '';
    }

    $template->set_var('start_block_last10mediaitems', COM_startBlock($LANG_MG10['last_10'] . $username));
    $template->set_var('start_block_useralbums', COM_startBlock($LANG_MG10['albums_owned'] . $username));
    $template->set_var('lang_thumbnail', $LANG_MG10['thumbnail']);
    $template->set_var('lang_title', $LANG_MG10['title']);
    $template->set_var('lang_album', $LANG_MG10['album']);
    $template->set_var('lang_album_description', $LANG_MG10['album_desc']);
    $template->set_var('lang_upload_date', $LANG_MG10['upload_date']);
    $template->set_var('end_block', COM_endBlock());

    $class = 0;

    $sql = "SELECT a.album_id,m.media_upload_time,m.media_id,m.media_filename,m.mime_type,m.media_mime_ext,m.media_title,m.remote_media,m.media_type FROM {$_TABLES['mg_albums']} as a LEFT JOIN {$_TABLES['mg_media_albums']} as ma
            on a.album_id=ma.album_id LEFT JOIN {$_TABLES['mg_media']} as m on ma.media_id=m.media_id WHERE
            m.media_user_id=" . $uid . " AND a.hidden=0 " . COM_getPermSQL('and') . " ORDER BY m.media_upload_time DESC LIMIT 5";

    $result = DB_query($sql);
    $mCount = 0;
    while ( $row = DB_fetchArray($result)) {
        $album_id = $row['album_id'];
        $album_title = strip_tags($MG_albums[$album_id]->title);
        $upload_time = MG_getUserDateTimeFormat($row['media_upload_time']);
        $url_media = $_MG_CONF['site_url'] . '/media.php?s=' . $row['media_id'];
        $url_album = $_MG_CONF['site_url'] . '/album.php?aid=' . $album_id;

        switch( $row['media_type'] ) {
            case 0 :    // standard image
                $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $row['media_filename'][0] . '/' . $row['media_filename'] . '.jpg';
                $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/disp/' . $row['media_filename'][0] .'/' . $row['media_filename'] . '.jpg');
                break;
            case 1 :    // video file
                switch ( $row['mime_type'] ) {
                    case 'application/x-shockwave-flash' :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/flash.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/flash.gif');
                        break;
                    case 'video/quicktime' :
                    case 'video/mpeg' :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/quicktime.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/quicktime.gif');
                        break;
                    case 'video/x-ms-asf' :
                    case 'video/x-ms-wvx' :
                    case 'video/x-ms-wm' :
                    case 'video/x-ms-wmx' :
                    case 'video/x-msvideo' :
                    case 'application/x-ms-wmz' :
                    case 'application/x-ms-wmd' :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/wmp.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/wmp.gif');
                        break;
                    default :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/video.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/video.gif');
                        break;
                }
                break;
            case 2 :    // music file
                $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/audio.gif';
                $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/audio.gif');
                break;
            case 4 :    // other files
                switch ($row['media_mime_ext']) {
                    case 'zip' :
                    case 'arj' :
                    case 'rar' :
                    case 'gz'  :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/zip.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/zip.gif');
                        break;
                    case 'pdf' :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/pdf.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/pdf.gif');
                        break;
                    default :
                        $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/generic.gif';
                        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/generic.gif');
                        break;
                }
                break;
            case 5 :
                $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/remote.png';
                $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/remote.png');
                break;
        }

        if ($msize == false ) {
            $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/missing.png';
            $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/missing.png');
        }
        $imgwidth = $msize[0];
        $imgheight = $msize[1];

        if ( $imgwidth > $imgheight ) {
            $ratio = $imgwidth / 120;
            $width = 120;
            $height = round($imgheight / $ratio);
        } else {
            $ratio = $imgheight / 120;
            $height = 120;
            $width = round($imgwidth / $ratio);
        }

        $template->set_var('mediaitem_image', '<img src="' . $url_thumb . '" width="' . $width . '" height="' . $height . '" border="0">');
        $template->set_var('mediaitem_begin_href', '<a href="' . $url_media . '">');
        $template->set_var('mediaitem_title', strip_tags($row['media_title']));
        $template->set_var('mediaitem_end_href', '</a>');
        $template->set_var('mediaitem_album_begin_href', '<a href="' . $url_album . '">');
        $template->set_var('mediaitem_album_title', $album_title);
        $template->set_var('mediaitem_date', $upload_time[0]);
        $template->set_var('rowclass', ($class % 2) ? '1' : '2');
        $template->parse('mediaitem_row', 'mrow', true);
        $class++;
        $mCount++;
    }
    // end of media block
    $template->parse('output', 'mblock', true);
    if ( $mCount != 0 ) {
        $retval .= $template->finish ($template->get_var('output'));
    }

    $template = new Template($_CONF['path'] . 'plugins/mediagallery/templates');
    $template->set_file(array(
        'mblock' => 'albumblock.thtml',
        'arow'   => 'albumrow.thtml'
    ));

    $template->set_var('start_block_useralbums', COM_startBlock($LANG_MG10['albums_owned'] . $username));
    $template->set_var('lang_thumbnail', $LANG_MG10['thumbnail']);
    $template->set_var('lang_album', $LANG_MG10['album']);
    $template->set_var('lang_album_description', $LANG_MG10['album_desc']);
    $template->set_var('end_block', COM_endBlock());

    $sql = "SELECT album_id,album_title,album_desc "
         . "FROM " . $_TABLES['mg_albums']
         . " WHERE owner_id=" . $uid . " AND hidden=0 " . COM_getPermSQL('and') . " LIMIT 10";

    $result = DB_query($sql);
    $aCount = 0;
    while ($row = DB_fetchArray($result)) {
        $aid        = $row['album_id'];
        $url_album  = $_MG_CONF['site_url'] . '/album.php?aid=' . $row['album_id'];
        $cover_file = $MG_albums[$aid]->findCover();
        $url_thumb  = $_MG_CONF['site_url'] . '/mediaobjects/tn/' . $cover_file[0] . '/' . $cover_file . '.jpg';
        $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/disp/' . $cover_file[0] .'/' . $cover_file . '.jpg');
        if ($msize == false ) {
            $url_thumb = $_MG_CONF['site_url'] . '/mediaobjects/empty.gif';
            $msize = @getimagesize($_MG_CONF['path_html'] . '/mediaobjects/empty.gif');
        }
        $imgwidth = $msize[0];
        $imgheight = $msize[1];

        if ( $imgwidth > $imgheight ) {
            $ratio = $imgwidth / 120;
            $width = 120;
            $height = round($imgheight / $ratio);
        } else {
            $ratio = $imgheight / 120;
            $height = 120;
            $width = round($imgwidth / $ratio);
        }
        $template->set_var('album_cover', '<img src="' . $url_thumb . '" width="' . $width . '" height="' . $height . '" border="0">');
        $template->set_var('album_begin_href', '<a href="' . $url_album . '">');
        $template->set_var('album_title', strip_tags($row['album_title']));
        $template->set_var('album_end_href', '</a>');
        $template->set_var('album_desc', strip_tags($row['album_desc']));
        $template->set_var('rowclass', ($class % 2) ? '1' : '2');
        $template->parse('useralbum_row', 'arow', true);
        $class++;
        $aCount++;
    }
    $template->parse('output', 'mblock', true);
    if ( $aCount != 0 ) {
        $retval .= $template->finish ($template->get_var('output'));
    }
    return $retval;
}

function phpblock_mg_menu() {
    global $_TABLES,$_CONF,$_USER,$_MG_CONF,$LANG_MG01;

    $retval =     '<h2>' . $LANG_MG01['configuration'] . '</h2>' . LB;
    $retval .=     '  <ul>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['admin_url'] . 'cfgedit.php">' . $LANG_MG01['system_options'] . '</a></li>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['admin_url'] . 'exif_admin.php">' . $LANG_MG01['exif_admin_header'] . '</a></li>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['admin_url'] . 'category.php">' . $LANG_MG01['category_manage_help'] . '</a></li>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['admin_url'] . 'resetdefaults.php">' . $LANG_MG01['reset_defaults'] . '</a></li>' . LB;
    $retval .=     '  </ul>' . LB;

    $retval .=     '<h2>' . $LANG_MG01['system_default_editor'] . '</h2>'  . LB;
    $retval .=     '  <ul>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['admin_url'] . 'defaults.php">' . $LANG_MG01['album_default_editor'] . '</a></li>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['admin_url'] . 'avdefaults.php">' . $LANG_MG01['av_default_editor'] . '</a></li>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['site_url'] . '/admin.php?album_id=0&amp;mode=globalperm&amp;a=1">' . $LANG_MG01['globalperm'] . '</a></li>' . LB;
    $retval .=     '    <li><a href="' . $_MG_CONF['site_url'] . '/admin.php?album_id=0&amp;mode=globalattr&amp;a=1">' . $LANG_MG01['globalattr'] . '</a></li>' . LB;
    $retval .=     '  </ul>' . LB;

    return $retval;
}

?>